import subprocess
import json



thing = subprocess.Popen('python overit.py gooey-seed-ui', stdout=subprocess.PIPE)
out, err = thing.communicate()
print(thing.returncode)
print(out)
print(err)

print(json.loads(out.decode('utf-8'))['--load'])



import subprocess
import gooey
import sys

# @gooey.Gooey()
# def main():
#     parser = gooey.GooeyParser()
#     args = parser.parse_args()
#
#     # startupinfo = subprocess.STARTUPINFO()
#     # startupinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
#
#     process = subprocess.Popen(
#         ["ping", "127.0.0.1", "-n", "5", ],
#         # startupinfo=startupinfo
#     )
#     process.wait()
#     if process.returncode != 0:
#         print("An error occurred :", process.returncode)
#         exit(1)
#
# if __name__ == '__main__':
#     main()


import subprocess
import gooey

@gooey.Gooey()
def main():
    parser = gooey.GooeyParser()
    args = parser.parse_args()

    process = subprocess.Popen(["ping", "127.0.0.1", "-n", "5", ])
    process.wait()
    if process.returncode != 0:
        print("An error occurred :", process.returncode)
        exit(1)

if __name__ == '__main__':
    main()


'''
Created on Dec 21, 2013
 __          __  _
 \ \        / / | |
  \ \  /\  / /__| | ___ ___  _ __ ___   ___
   \ \/  \/ / _ \ |/ __/ _ \| '_ ` _ \ / _ \
    \  /\  /  __/ | (_| (_) | | | | | |  __/
  ___\/__\/ \___|_|\___\___/|_| |_| |_|\___|
 |__   __|
    | | ___
    | |/ _ \
    | | (_) |
   _|_|\___/                    _ _
  / ____|                      | | |
 | |  __  ___   ___   ___ _   _| | |
 | | |_ |/ _ \ / _ \ / _ \ | | | | |
 | |__| | (_) | (_) |  __/ |_| |_|_|
  \_____|\___/ \___/ \___|\__, (_|_)
                           __/ |
                          |___/

@author: Chris
'''

from argparse import ArgumentParser
from collections import OrderedDict

from gooey.python_bindings.gooey_decorator import Gooey
from gooey.python_bindings.gooey_parser import GooeyParser


@Gooey(
    sidebar_title="Your Custom Title",
    show_sidebar=True,
    dump_build_config=True,
    requires_shell=False,
    about={
        'name': 'Howdy',
        'version': '1.2.1',
        'copyright': '(C) yo mama'
    }
    # language='russian'
)
def main():
    import sys
    print(sys.argv)
    desc = "Example application to show Gooey's various widgets"
    file_help_msg = "Name of the file you want to process"
    parser = GooeyParser(description=desc, add_help=False)

    # parser.add_argument('--textfield', default=2, widget="TextField", gooey_options={'full_width': True})
    # parser.add_argument('--textarea', default="oneline twoline", widget='Textarea')
    # parser.add_argument('--password', default="hunter42", widget='PasswordField')
    # parser.add_argument('--commandfield', default="cmdr", widget='CommandField')
    # parser.add_argument('--dropdown',
    #                     choices=["one", "two"], default="two", widget='Dropdown')
    # parser.add_argument('--listboxie',
    #                 nargs='+',
    #                 default=['Option three', 'Option four'],
    #                 choices=['Option one', 'Option two', 'Option three',
    #                          'Option four'],
    #                 widget='Listbox',
    #                 gooey_options={
    #                     'height': 300,
    #                     'validate': '',
    #                     'heading_color': 'ff0000',
    #                     'text_color': '',
    #                     'hide_heading': False,
    #                     'hide_text': True,
    #                 }
    #             )
    # parser.add_argument('-c', '--counter', default=3, action='count', widget='Counter')
    # #
    # parser.add_argument("-o", "--overwrite", action="store_true",
    #                             default=True,
    #                             widget='CheckBox')
    #
    # ### Mutex Group ###
    # verbosity = parser.add_mutually_exclusive_group(
    #     required=True,
    #     gooey_options={
    #         'initial_selection': 1
    #     }
    # )
    # verbosity.add_argument(
    #     '--mutexone',
    #     default=True,
    #     action='store_true',
    #     help="Show more details")
    #
    # verbosity.add_argument(
    #     '--mutextwo',
    #     default='mut-2',
    #     widget='TextField')

    parser.add_argument("--filechooser", default="fc-value", widget='FileChooser', gooey_options={
        'defaultFile': 'Sup nigga',
        'message': 'Sup fam',
        'wildcard': 'nig juice'
    })
    parser.add_argument("--filesaver", default="fs-value", widget='FileSaver')
    parser.add_argument("--dirchooser", default="dc-value", widget='DirChooser')
    parser.add_argument("--datechooser", default="2015-01-01", widget='DateChooser')
    parser.add_argument("--multifilechooser", default="2015-01-01", widget='MultiFileChooser')
    parser.add_argument("--multidirchooser", default="2015-01-01", widget='MultiDirChooser')


    dest_vars = [
        'textfield',
        'textarea',
        'password',
        'commandfield',
        'dropdown',
        'listboxie',
        'counter',
        'overwrite',
        'mutextwo',
        'filechooser',
        'filesaver',
        'dirchooser',
        'datechooser'

    ]


    args = parser.parse_args()
    for i in dest_vars:
        assert getattr(args, i) is not None
    print("Success")


if __name__ == '__main__':
    main()



from gooey import Gooey
from gooey import GooeyParser

@Gooey(
    program_name='ICC-OBS Version 0.1',
    show_stop_warning=False,
    force_stop_is_error=False,
    disable_progress_bar_animation=True,
    required_cols=1,
    advanced=True,
    navigation='TABBED',
	menu=[{
        'name': 'File',
        'items': [{
                'type': 'AboutDialog',
                'menuTitle': 'About',
                'name': 'Gooey Layout Demo',
                'description': 'An example of Gooey\'s layout flexibility',
                'version': '1.2.1',
                'copyright': '2018',
                'website': 'https://github.com/chriskiehl/Gooey',
                'developer': 'http://chriskiehl.com/',
                'license': 'MIT'
            }, {
                'type': 'MessageDialog',
                'menuTitle': 'Information',
                'caption': 'My Message',
                'message': 'I am demoing an informational dialog!'
            }, {
                'type': 'Link',
                'menuTitle': 'Get Data',
                'url': 'https://data.ccca.ac.at/group/climaproof'
            }]
        },{
        'name': 'Help',
        'items': [{
            'type': 'Link',
            'menuTitle': 'Documentation',
            'url': 'https://www.readthedocs.com/foo'
        }]
    }]
)
def main():
	parser = GooeyParser(description='Example About Dialoge')
	parser.add_argument('filename', help="name of the file to process")
	args = parser.parse_args()

if __name__ == "__main__":
    main()


import wx

from gooey.gui import events
from gooey.gui.pubsub import pub
from gooey.gui.util import wx_util


class Tabbar(wx.Panel):
    def __init__(self, parent, buildSpec, configPanels, *args, **kwargs):
        super(Tabbar, self).__init__(parent, *args, **kwargs)
        self._parent = parent
        self.notebook = wx.Notebook(self, style=wx.BK_DEFAULT)
        self.buildSpec = buildSpec
        self.configPanels = configPanels
        self.options = list(self.buildSpec['widgets'].keys())
        self.layoutComponent()


    def layoutComponent(self):
        for group, panel in zip(self.options, self.configPanels):
            panel.Reparent( self.notebook)
            self.notebook.AddPage(panel, group)
            self.notebook.Layout()

        sizer = wx.BoxSizer(wx.VERTICAL)
        sizer.Add(self.notebook, 1, wx.EXPAND)
        self.SetSizer(sizer)
        self.Layout()

    def getSelectedGroup(self):
        return self.options[self.notebook.Selection]

    def getActiveConfig(self):
        return self.configPanels[self.notebook.Selection]

    def show(self, b):
        self.Show(b)



import sys
import wx

from gooey.gui import events
from gooey.gui.lang.i18n import _
from gooey.gui.pubsub import pub
from gooey.gui.components.mouse import notifyMouseEvent


class Footer(wx.Panel):
    '''
    Footer section used on the configuration
    screen of the application
    '''

    def __init__(self, parent, buildSpec, **kwargs):
        wx.Panel.__init__(self, parent, **kwargs)
        self.buildSpec = buildSpec

        self.SetMinSize((30, 53))
        # TODO: The was set to True for the timer addition
        #       however, it leads to 'tearing' issues when resizing
        #       the GUI in windows. Disabling until I can dig into it.
        self.SetDoubleBuffered(False)
        # components
        self.cancel_button = None
        self.start_button = None
        self.progress_bar = None
        self.close_button = None
        self.stop_button = None
        self.restart_button = None
        self.edit_button = None
        self.buttons = []

        self.layouts = {}

        self._init_components()
        self._do_layout()

        for button in self.buttons:
            self.Bind(wx.EVT_BUTTON, self.dispatch_click, button)
            self.Bind(wx.EVT_LEFT_DOWN, notifyMouseEvent, button)
        self.Bind(wx.EVT_LEFT_DOWN, notifyMouseEvent)


    def updateTimeRemaining(self,*args,**kwargs):
        estimate_time_remaining = kwargs.get('estimatedRemaining')
        elapsed_time_value = kwargs.get('elapsed_time')
        if elapsed_time_value is None:
            return
        elif estimate_time_remaining is not None:
            self.time_remaining_text.SetLabel(f"{elapsed_time_value}<{estimate_time_remaining}")
            return
        else:
            self.time_remaining_text.SetLabel(f"{elapsed_time_value}")


    def updateProgressBar(self, *args, **kwargs):
        '''
         value, disable_animation=False
        :param args:
        :param kwargs:
        :return:
        '''
        value = kwargs.get('progress')
        pb = self.progress_bar
        if value is None:
            return
        if value < 0:
            pb.Pulse()
        else:
            value = min(int(value), pb.GetRange())
            if pb.GetValue() != value:
                # Windows 7 progress bar animation hack
                # http://stackoverflow.com/questions/5332616/disabling-net-progressbar-animation-when-changing-value
                if self.buildSpec['disable_progress_bar_animation'] \
                        and sys.platform.startswith("win"):
                    if pb.GetRange() == value:
                        pb.SetValue(value)
                        pb.SetValue(value - 1)
                    else:
                        pb.SetValue(value + 1)
                pb.SetValue(value)


    def showButtons(self, *buttonsToShow):
        for button in self.buttons:
            button.Show(False)
        for button in buttonsToShow:
            getattr(self, button).Show(True)
        self.Layout()


    def _init_components(self):
        self.cancel_button = self.button(_('cancel'), wx.ID_CANCEL, event_id=events.WINDOW_CANCEL)
        self.stop_button = self.button(_('stop'), wx.ID_OK, event_id=events.WINDOW_STOP)
        self.start_button = self.button(_('start'), wx.ID_OK, event_id=int(events.WINDOW_START))
        self.close_button = self.button(_("close"), wx.ID_OK, event_id=int(events.WINDOW_CLOSE))
        self.restart_button = self.button(_('restart'), wx.ID_OK, event_id=int(events.WINDOW_RESTART))
        self.edit_button = self.button(_('edit'), wx.ID_OK, event_id=int(events.WINDOW_EDIT))

        self.progress_bar = wx.Gauge(self, range=100)

        self.time_remaining_text = wx.StaticText(self)

        self.buttons = [self.cancel_button, self.start_button,
                        self.stop_button, self.close_button,
                        self.restart_button, self.edit_button]

        if self.buildSpec['disable_stop_button']:
            self.stop_button.Enable(False)


    def _do_layout(self):
        self.SetBackgroundColour(self.buildSpec['footer_bg_color'])
        self.stop_button.Hide()
        self.restart_button.Hide()

        v_sizer = wx.BoxSizer(wx.VERTICAL)
        h_sizer = wx.BoxSizer(wx.HORIZONTAL)

        h_sizer.Add(self.progress_bar, 1,
                    wx.ALIGN_LEFT | wx.ALIGN_CENTER_VERTICAL | wx.LEFT, 20)
        
        h_sizer.Add(self.time_remaining_text,0,wx.LEFT | wx.ALIGN_CENTER_VERTICAL, 20)

        h_sizer.AddStretchSpacer(1)
        h_sizer.Add(self.cancel_button, 0,wx.RIGHT, 20)
        h_sizer.Add(self.start_button, 0, wx.RIGHT, 20)
        h_sizer.Add(self.stop_button, 0, wx.RIGHT, 20)

        v_sizer.AddStretchSpacer(1)
        v_sizer.Add(h_sizer, 0, wx.EXPAND)

        h_sizer.Add(self.edit_button, 0, wx.RIGHT, 10)
        h_sizer.Add(self.restart_button, 0, wx.RIGHT, 10)
        h_sizer.Add(self.close_button, 0, wx.RIGHT, 20)
        self.edit_button.Hide()
        self.restart_button.Hide()
        self.close_button.Hide()
        self.progress_bar.Hide()

        v_sizer.AddStretchSpacer(1)
        self.SetSizer(v_sizer)

    def button(self, label=None, style=None, event_id=-1):
        return wx.Button(
            parent=self,
            id=event_id,
            size=(90, -1),
            label=label,
            style=style)

    def dispatch_click(self, event):
        pub.send_message(event.GetId())

    def hide_all_buttons(self):
        for button in self.buttons:
            button.Hide()



import re
import unittest

from gooey.tests import *

from gooey.gui.util.time import get_current_time,get_elapsed_time,estimate_time_remaining,format_interval


class TestTimeUtil(unittest.TestCase):
    def test_time_elapsed(self):
        # Check that time elapsed is greater than zero
        _start_time = get_current_time()
        elapsed = get_elapsed_time(_start_time)
        self.assertGreater(elapsed,0)

    def test_time_remaining(self):
        # Check that time elapsed is greater than zero
        _start_time = get_current_time()
        remaining = estimate_time_remaining(30,_start_time)
        self.assertGreater(remaining,0)

    def test_current_time(self):
        # Test that current time is greater than zero
        _start_time = get_current_time()
        self.assertGreater(_start_time,0)

    
    def test_format_interval(self):
        # Test same as TQDM https://github.com/tqdm/tqdm/blob/0cd9448b2bc08125e74538a2aea6af42ee1a7b6f/tqdm/tests/tests_tqdm.py#L234
        # but in unittest form

        self.assertEqual(format_interval(60), '01:00')
        self.assertEqual(format_interval(6160), '1:42:40')
        self.assertEqual(format_interval(238113), '66:08:33')



import argparse
from gooey import Gooey
from gooey import GooeyParser

@Gooey
def initOptParser():
    defaultFolderPath = "./TEST"
    archivePath = "./Archives"

    parser = argparse.ArgumentParser(description="Copy files to specified location")
    parser.add_argument('files', metavar='file', type=str, nargs='+',
                         help='file(s) or directory that you wish to copy' )
    # parser.add_argument('-p', '--path', metavar='path',dest='path',  type=str,
    #                     help='Path which will be considered as root of all projects. Default is currently : ' + defaultFolderPath,
    #                     default=defaultFolderPath)
    # parser.add_argument('projectName', metavar='projectName', type=str,
    #                     help='The project you wish to retrieve/add files to/from.')
    # parser.add_argument('-v', '--version', metavar='versionName', type=str,
    #                     help='The name of the directory which will be created during an update. By default, this will be : DATE_TIME.')
    # parser.add_argument('-o', '--overwrite',
    #                     help='Overwrites the files in the current version of specified project. (no new directory creation)', action="store_true")
    # parser.add_argument('-m', '--message', metavar='logMessage', type=str, help='Use to specify a log message which will be put in a .txt file. (default : commit.txt)')
    # parser.add_argument('-g', '--get', dest='method', action='store_const', help='Retrieve files from project (last version by default)')
    # parser.add_argument('-l', '--lock', action="store_true",
    #                     help='Locks the current project. Can be overriden/ignored on demand. (Will ask other users if they want to pull files)'+
    #                         'Unlocked when next push from the locking user is made')
    # parser.add_argument('user', metavar='userName', type=str, help='Specify your name.')
    # parser.add_argument('-a', '--archive', metavar='archivePath', type=str, help='Use to specify a directory which will be used as an archive. Current default is : ' + archivePath)
    # parser.add_argument('-s', '--store', metavar="destPath", help='Use to specify where you want the files retrieved from the project to be copied.')

    args = parser.parse_args()
    args.method() # Either get() or push(). For now i'm using two factice functions who just print their name.
    return (args)

if __name__ == '__main__':
  initOptParser()



from gooey.gui.components.widgets.core.text_input import PasswordInput
from gooey.gui.components.widgets.textfield import TextField


__ALL__ = ('PasswordField',)

class PasswordField(TextField):
    widget_class = PasswordInput

    def __init__(self, *args, **kwargs):
        super(PasswordField, self).__init__(*args, **kwargs)




import argparse
from gooey import Gooey, GooeyParser

# @Gooey
def main():
    parser = GooeyParser()
    # parser.add_argument("--enable-foo", action="store_true", help="enable the foo option")
    # parser.add_argument("--disable-bar",action="store_true",  help="disable the bar option", gooey_options={
    #     'show_label': True
    # }# , widget='BlockCheckbox'
    #                     )
    parser.add_argument('--verbose', '-v', action='count', default=0)
    args = parser.parse_args()

    print(args)


main()








import argparse



from gooey import GooeyParser, Gooey

@Gooey(program_description="DUCK MY FAT COCK")
def main():
    parser = argparse.ArgumentParser(description="Hello world!")
    parser.add_argument(
        nargs="*",
        default=["foo bar"],
        dest="multi_arg",
    )
    import time
    args = parser.parse_args()
    for i in range(1000):
        # import time
        # # time.sleep(1)
        # print("HI")
        print(time.time())
    print(args)


if __name__ == "__main__":
    main()


'''
A Gooey example showing use of richtext display in the console pannel.
'''
import os

from gooey import Gooey, GooeyParser

@Gooey()
def main():
    parser = GooeyParser(description='Just display the console')

    parser.add_argument('--host', help='Ze host!', default=os.environ.get('HOST'))
    args = parser.parse_args()

if __name__ == '__main__':
    main()


import argparse
from gooey import Gooey
from gooey import GooeyParser


class CustomHelpFormatter(argparse.HelpFormatter):

    def _format_action(self, action):
        a = 10
        super(CustomHelpFormatter, self)._format_action(action)






@Gooey(program_name='some program')
def main():
    someparser = argparse.ArgumentParser(description='Some words', formatter_class=CustomHelpFormatter)
    someparser = GooeyParser(description='Some words', formatter_class=CustomHelpFormatter)
    someparsers = someparser.add_subparsers(dest='someplace')
    somesubparser = someparsers.add_parser('someoption')
    croc_facts = somesubparser.add_argument_group(
        'Just Crocodile Things',
        description='There are 13 species of crocodiles, so there are many different ' +
                    'sizes of crocodile. The smallest crocodile is the dwarf crocodile. ' +
                    'It grows to about 5.6 feet (1.7 meters) in length and weighs 13 to 15 pounds ',
        gooey_options={
            'show_border': True,
        }
    )
    someothersubparser = someparsers.add_parser('someotheroption', help='foo')
    someoption = croc_facts.add_argument('-somecrocodile', action='store_true', help='Nothing to see here, move along.')
    someparser.parse_args()


main()



SIDEBAR = 'SIDEBAR'
TABBED = 'TABBED'
INLINE = 'INLINE'
HIDDEN = 'HIDDEN'

FONTWEIGHT_THIN = 100
FONTWEIGHT_EXTRALIGHT = 200
FONTWEIGHT_LIGHT = 300
FONTWEIGHT_NORMAL = 400
FONTWEIGHT_MEDIUM = 500
FONTWEIGHT_SEMIBOLD = 600
FONTWEIGHT_BOLD = 700
FONTWEIGHT_EXTRABOLD = 800
FONTWEIGHT_HEAVY = 900
FONTWEIGHT_EXTRAHEAVY = 1000



import wx

from gooey.gui.util.filedrop import FileDrop
from gooey.util.functional import merge
from gooey.gui.components.mouse import notifyMouseEvent


class TextInput(wx.Panel):
    def __init__(self, parent, *args, **kwargs):
        super(TextInput, self).__init__(parent)
        self.widget = wx.TextCtrl(self, *args, **kwargs)
        dt = FileDrop(self.widget)
        self.widget.SetDropTarget(dt)
        self.widget.SetMinSize((0, -1))
        self.widget.SetDoubleBuffered(True)
        self.widget.AppendText('')
        self.layout()

        self.widget.Bind(wx.EVT_LEFT_DOWN, notifyMouseEvent)

    def layout(self):
        sizer = wx.BoxSizer(wx.VERTICAL)
        sizer.Add(self.widget, 0, wx.EXPAND)
        self.SetSizer(sizer)


    def setValue(self, value):
        self.widget.Clear()
        self.widget.AppendText(str(value))
        self.widget.SetInsertionPoint(0)

    def getValue(self):
        return self.widget.GetValue()

    def SetHint(self, value):
        self.widget.SetHint(value)

    def SetDropTarget(self, target):
        self.widget.SetDropTarget(target)



def PasswordInput(_, parent, *args, **kwargs):
    style = {'style': wx.TE_PASSWORD}
    return TextInput(parent, *args, **merge(kwargs, style))


def MultilineTextInput(_, parent, *args, **kwargs):
    style = {'style': wx.TE_MULTILINE}
    return TextInput(parent, *args, **merge(kwargs, style))



import re
import unittest

from gooey.gui.processor import ProcessController


class TestProcessor(unittest.TestCase):

    def test_extract_progress(self):
        # should pull out a number based on the supplied
        # regex and expression
        processor = ProcessController(r"^progress: (\d+)%$", None, False, 'utf-8')
        self.assertEqual(processor._extract_progress(b'progress: 50%'), 50)

        processor = ProcessController(r"total: (\d+)%$", None, False, 'utf-8')
        self.assertEqual(processor._extract_progress(b'my cool total: 100%'), 100)

    def test_extract_progress_returns_none_if_no_regex_supplied(self):
        processor = ProcessController(None, None, False, 'utf-8')
        self.assertIsNone(processor._extract_progress(b'Total progress: 100%'))


    def test_extract_progress_returns_none_if_no_match_found(self):
        processor = ProcessController(r'(\d+)%$', None, False, 'utf-8')
        self.assertIsNone(processor._extract_progress(b'No match in dis string'))


    def test_eval_progress(self):
        # given a match in the string, should eval the result
        regex = r'(\d+)/(\d+)$'
        processor = ProcessController(regex, r'x[0] / x[1]', False,False, 'utf-8')
        match = re.search(regex, '50/50')
        self.assertEqual(processor._eval_progress(match), 1.0)
    def test_eval_progress_returns_none_on_failure(self):
        # given a match in the string, should eval the result
        regex = r'(\d+)/(\d+)$'
        processor = ProcessController(regex, r'x[0] *^/* x[1]', False, False,'utf-8')
        match = re.search(regex, '50/50')
        self.assertIsNone(processor._eval_progress(match))



from argparse import *
from pathlib import Path
from gooey import Gooey

@Gooey
def main():
    parser = ArgumentParser()
    parser.add_argument("--foo", type=FileType("r"))
    parser.add_argument("--bar", type=Path)
    print(parser.parse_args())

main()




from .base_dialog import BaseDialog
from gooey.gui.three_to_four import Classes
from gooey.gui.lang.i18n import _


class CalendarDlg(BaseDialog):
    def __init__(self, parent):
        super(CalendarDlg, self).__init__(parent, 
            pickerClass=Classes.DatePickerCtrl,
            pickerGetter=lambda datepicker: datepicker.GetValue().FormatISODate(),
            localizedPickerLabel=_('select_date'))


'''
Created on Dec 21, 2013
 __          __  _
 \ \        / / | |
  \ \  /\  / /__| | ___ ___  _ __ ___   ___
   \ \/  \/ / _ \ |/ __/ _ \| '_ ` _ \ / _ \
    \  /\  /  __/ | (_| (_) | | | | | |  __/
  ___\/__\/ \___|_|\___\___/|_| |_| |_|\___|
 |__   __|
    | | ___
    | |/ _ \
    | | (_) |
   _|_|\___/                    _ _
  / ____|                      | | |
 | |  __  ___   ___   ___ _   _| | |
 | | |_ |/ _ \ / _ \ / _ \ | | | | |
 | |__| | (_) | (_) |  __/ |_| |_|_|
  \_____|\___/ \___/ \___|\__, (_|_)
                           __/ |
                          |___/

@author: Chris
'''
import csv
import zipfile
from io import TextIOWrapper

from gooey.python_bindings.gooey_decorator import Gooey
from gooey.python_bindings.gooey_parser import GooeyParser

with zipfile.ZipFile(
        r'C:\Users\Chris\Downloads\simplemaps_worldcities_basicv1.71\worldcities.zip') as zf:
    with zf.open('worldcities.csv', 'r') as f:
        reader = csv.reader(TextIOWrapper(f, 'utf-8'))
        locations = ['{} - {}'.format(x[4], x[1]) for x in reader][1:][:5000]


# locations = ["Alabama", "Alaska", '...', "Wyoming"]

@Gooey(program_name='Square BnB')
def version1():
    parser = GooeyParser(
        description='Welcome to SquareBnb travel. Wherever you go, we have a place for you')
    # basic details
    parser.add_argument('location', choices=locations, help='Where are you going?')
    parser.add_argument('check-in', help='Add Dates')
    parser.add_argument('check-out', help='Add Dates')
    parser.add_argument('guests', help='Add Guests')

    # pricing
    parser.add_argument('--min-price', help='Minimum Price')
    parser.add_argument('--max-price', help='Minimum Price')

    # popular filters
    parser.add_argument('--rooms', help='How many rooms do you need?')
    parser.add_argument('--beds', help='How many beds do you need?')
    parser.add_argument('--bathrooms', help='How many bathrooms do you need?')
    parser.add_argument('--entire-place', action='store_true',
                        help='Have the whole place to yourself')
    parser.add_argument('--house', action='store_true', help='No apartments, plz')
    parser.add_argument('--wifi', action='store_true', help='Internet is a must!')
    parser.add_argument('--kitchen', action='store_true', help='A place to cook')

    args = parser.parse_args()
    print(args)
    # ... rest of program


@Gooey(program_name='Square BnB v2.0')
def version2():
    parser = GooeyParser(
        description='Welcome to SquareBnb travel. Wherever you go, we have a place for you')

    location = parser.add_argument_group('Find a place to stay', gooey_options={
        'show_border': True
    })
    location.add_argument('location', choices=locations, help='Where are you going?')
    location.add_argument('check-in', help='Add Dates')
    location.add_argument('check-out', help='Add Dates')
    location.add_argument('guests', help='Add Guests')

    # pricing
    pricing = parser.add_argument_group('Pricing', gooey_options={
        'show_border': True
    })
    pricing.add_argument('--min-price', help='Minimum Price')
    pricing.add_argument('--max-price', help='Minimum Price')

    # popular filters
    filters = parser.add_argument_group('Popular Filters', gooey_options={
        'show_border': True
    })
    filters.add_argument('--rooms', help='How many rooms do you need?')
    filters.add_argument('--beds', help='How many beds do you need?')
    filters.add_argument('--bathrooms', help='How many bathrooms do you need?')
    filters.add_argument('--entire-place', action='store_true',
                         help='Have the whole place to yourself')
    filters.add_argument('--house', action='store_true', help='No apartments, plz')
    filters.add_argument('--wifi', action='store_true', help='Internet is a must!')
    filters.add_argument('--kitchen', action='store_true', help='A place to cook')

    args = parser.parse_args()
    print(args)
    # ... rest of program


@Gooey(program_name='Square BnB v3.0')
def version3():
    parser = GooeyParser(
        description='Welcome to SquareBnb travel. Wherever you go, we have a place for you')

    location = parser.add_argument_group('Find a place to stay', gooey_options={
        'show_border': True
    })
    # updated!
    location.add_argument('location', choices=locations, help='Where are you going?',
                          gooey_options={
                              'full_width': True
                          })
    # updated!
    location.add_argument('guests', help='Add Guests', gooey_options={'full_width': True})
    location.add_argument('check-in', help='Add Dates')
    location.add_argument('check-out', help='Add Dates')

    # pricing
    pricing = parser.add_argument_group('Pricing', gooey_options={
        'show_border': True
    })
    pricing.add_argument('--min-price', help='Minimum Price')
    pricing.add_argument('--max-price', help='Minimum Price')

    # popular filters
    filters = parser.add_argument_group('Popular Filters', gooey_options={
        'show_border': True
    })
    filters.add_argument('--rooms', help='How many rooms do you need?')
    filters.add_argument('--beds', help='How many beds do you need?')
    filters.add_argument('--bathrooms', help='How many bathrooms do you need?')
    filters.add_argument('--entire-place', action='store_true',
                         help='Have the whole place to yourself')
    filters.add_argument('--house', action='store_true', help='No apartments, plz')
    filters.add_argument('--wifi', action='store_true', help='Internet is a must!')
    filters.add_argument('--kitchen', action='store_true', help='A place to cook')

    args = parser.parse_args()
    print(args)
    # ... rest of program


@Gooey(program_name='Square BnB v4.0')
def version4():
    parser = GooeyParser(
        description='Welcome to SquareBnb travel. Wherever you go, we have a place for you')

    location = parser.add_argument_group('Find a place to stay', gooey_options={
        'show_border': True
    })
    location.add_argument('location', choices=locations, help='Where are you going?',
                          gooey_options={
                              'full_width': True
                          })
    location.add_argument('guests', help='Add Guests', gooey_options={'full_width': True})
    location.add_argument('check-in', help='Add Dates')
    location.add_argument('check-out', help='Add Dates')

    # pricing
    pricing = parser.add_argument_group('Pricing', gooey_options={
        'show_border': True
    })
    pricing.add_argument('--min-price', help='Minimum Price')
    pricing.add_argument('--max-price', help='Minimum Price')

    # popular filters
    filters = parser.add_argument_group('Popular Filters', gooey_options={
        'show_border': True,
    })
    # 0. new! This is required to get the group to display..
    filters.add_argument('--ignore-me', gooey_options={'visible': False})
    # 1. new!
    housing = filters.add_argument_group('Rooms and Beds', gooey_options={
        'show_border': True,
        # 2. puts all children in a single column
        'columns': 1
    })
    # 3. updated!
    housing.add_argument('--rooms', help='How many rooms do you need?')
    housing.add_argument('--beds', help='How many beds do you need?')
    housing.add_argument('--bathrooms', help='How many bathrooms do you need?')

    # 4. new!
    ammenities = filters.add_argument_group('Amenities', gooey_options={
        'show_border': True,
        # 5. 2 cols for the checkboxes
        'columns': 2
    })
    # updated!
    ammenities.add_argument('--entire-place', action='store_true',
                            help='Have the whole place to yourself')
    ammenities.add_argument('--house', action='store_true', help='No apartments, plz')
    ammenities.add_argument('--wifi', action='store_true', help='Internet is a must!')
    ammenities.add_argument('--kitchen', action='store_true', help='A place to cook')

    args = parser.parse_args()
    print(args)
    # ... rest of program


@Gooey(program_name='Square BnB v5.0')
def version5():
    parser = GooeyParser(
        description='Welcome to SquareBnb travel. Wherever you go, we have a place for you')

    location = parser.add_argument_group('Find a place to stay', gooey_options={
        'show_border': True
    })
    location.add_argument(
        'location',
        choices=locations,
        help='Where are you going?',
        widget='FilterableDropdown',
        gooey_options={
            'full_width': True
        })
    location.add_argument('guests', help='Add Guests', gooey_options={'full_width': True})
    location.add_argument('check-in', help='Add Dates')
    location.add_argument('check-out', help='Add Dates')

    pricing = parser.add_argument_group('Pricing', gooey_options={
        'show_border': True
    })
    pricing.add_argument('--min-price', help='Minimum Price')
    pricing.add_argument('--max-price', help='Minimum Price')

    filters = parser.add_argument_group('Popular Filters', gooey_options={
        'show_border': True,
    })
    filters.add_argument('--ignore-me', gooey_options={'visible': False})
    housing = filters.add_argument_group('Rooms and Beds', gooey_options={
        'show_border': True,
        # 2. puts all children in a single column
        'columns': 1
    })
    housing.add_argument('--rooms', help='How many rooms do you need?')
    housing.add_argument('--beds', help='How many beds do you need?')
    housing.add_argument('--bathrooms', help='How many bathrooms do you need?')

    ammenities = filters.add_argument_group('Amenities', gooey_options={
        'show_border': True,
        # 5. 2 cols for the checkboxes
        'columns': 2
    })
    ammenities.add_argument('--entire-place', action='store_true',
                            help='Have the whole place to yourself')
    ammenities.add_argument('--house', action='store_true', help='No apartments, plz')
    ammenities.add_argument('--wifi', action='store_true', help='Internet is a must!')
    ammenities.add_argument('--kitchen', action='store_true', help='A place to cook')

    args = parser.parse_args()
    print(args)
    # ... rest of program


@Gooey(program_name='Square BnB v6.0')
def version6():
    parser = GooeyParser(
        description='Welcome to SquareBnb travel. Wherever you go, we have a place for you')

    location = parser.add_argument_group('Find a place to stay', gooey_options={
        'show_border': True
    })
    location.add_argument(
        'location',
        choices=locations,
        help='Where are you going?',
        widget='FilterableDropdown',
        gooey_options={
            'full_width': True
        })
    location.add_argument(
        'guests',
        help='Add Guests',
        choices=range(11),
        gooey_options={'full_width': True})
    location.add_argument(
        'check-in',
        metavar='Check in',
        widget='DateChooser',
        help='Add Dates')
    location.add_argument(
        'check-out',
        metavar='Check out',
        widget='DateChooser',
        help='Add Dates')

    pricing = parser.add_argument_group('Pricing', gooey_options={
        'show_border': True
    })
    pricing.add_argument('--min-price', help='Minimum Price')
    pricing.add_argument('--max-price', help='Minimum Price')

    filters = parser.add_argument_group('Popular Filters', gooey_options={
        'show_border': True,
    })
    filters.add_argument('--ignore-me', gooey_options={'visible': False})
    housing = filters.add_argument_group('Rooms and Beds', gooey_options={
        'show_border': True,
        # 2. puts all children in a single column
        'columns': 1
    })
    housing.add_argument('--rooms', choices=range(11), help='How many rooms do you need?')
    housing.add_argument('--beds', choices=range(11), help='How many beds do you need?')
    housing.add_argument('--bathrooms', choices=range(11), help='How many bathrooms do you need?')

    ammenities = filters.add_argument_group('Amenities', gooey_options={
        'show_border': True,
        # 5. 2 cols for the checkboxes
        'columns': 2
    })
    ammenities.add_argument('--entire-place', action='store_true',
                            help='Have the whole place to yourself')
    ammenities.add_argument('--house', action='store_true', help='No apartments, plz')
    ammenities.add_argument('--wifi', action='store_true', help='Internet is a must!')
    ammenities.add_argument('--kitchen', action='store_true', help='A place to cook')

    args = parser.parse_args()
    print(args)
    # ... rest of program


@Gooey(program_name='Square BnB v8.0')
def version8():
    parser = GooeyParser(
        description='Welcome to SquareBnb travel. Wherever you go, we have a place for you')

    location = parser.add_argument_group('Find a place to stay', gooey_options={
        'show_border': True
    })
    location.add_argument(
        'location',
        metavar='Location',
        choices=locations,
        help='Where are you going?',
        widget='FilterableDropdown',
        gooey_options={
            'full_width': True
        })
    location.add_argument(
        'guests',
        metavar='Guests',
        help='Add Guests',
        choices=range(11),
        gooey_options={'full_width': True})
    location.add_argument(
        'check-in',
        metavar='Check in',
        widget='DateChooser',
        help='Add Dates')
    location.add_argument(
        'check-out',
        metavar='Check out',
        widget='DateChooser',
        help='Add Dates')

    pricing = parser.add_argument_group('Pricing', gooey_options={
        'show_border': True
    })
    pricing.add_argument(
        '--min-price',
        help='Minimum Price',
        gooey_options={'show_help': False, 'label_color': '#2e2424'})
    pricing.add_argument(
        '--max-price',
        help='Maximum Price',
        gooey_options={'show_help': False, 'label_color': 1234})

    # FILTERS
    filters = parser.add_argument_group('Popular Filters', gooey_options={
        'show_border': True,
    })
    filters.add_argument('--ignore-me', gooey_options={'visible': False})
    housing = filters.add_argument_group('Rooms and Beds', gooey_options={
        'show_border': True,
        'columns': 1
    })
    housing.add_argument(
        '--rooms',
        metavar='Rooms',
        choices=range(11), help='How many rooms do you need?')
    housing.add_argument(
        '--beds',
        metavar='Beds',
        choices=range(11), help='How many beds do you need?')
    housing.add_argument(
        '--bathrooms',
        metavar='Bathrooms',
        choices=range(11), help='How many bathrooms do you need?')

    ammenities = filters.add_argument_group('Amenities', gooey_options={
        'show_border': True,
        'columns': 2
    })
    ammenities.add_argument(
        '--entire-place',
        metavar='Entire Place',
        action='store_true',
        help='Have the whole place to yourself')
    ammenities.add_argument(
        '--house',
        metavar='House',
        action='store_true', help='No apartments, plz')
    ammenities.add_argument(
        '--wifi',
        metavar='WIFI',
        action='store_true', help='Internet is a must!')
    ammenities.add_argument(
        '--kitchen',
        metavar='Kitchen',
        action='store_true', help='A place to cook')

    args = parser.parse_args()
    print(args)
    # ... rest of program


if __name__ == '__main__':
    # version1()
    # version2()
    # version3()
    # version4()
    # version5()
    # version6()
    # version7()
    version8()

"""
search_options = parser.add_argument_group(
        'Search Options',
        'Customize the search options',
        gooey_options={
            'show_border': True,
            'columns': 2,
            'margin_top': 25
        }
    )

    search_options.add_argument('--query', help='base search string'
                                    , gooey_options={'full_width': True}
                                    )
    #
    search_flags = search_options.add_argument_group('Flags',
                                                     gooey_options={'show_border': False}
                                                     )
    search_flags.add_argument('--buy-it-now',
                              metavar='Buy it Now',
                              help="Will immediately purchase if possible",
                              action='store_true',
                              widget='BlockCheckbox',
                              gooey_options={
                                  'label_color': '#4B5F83',
                                  'checkbox_label': 'Enable'
                              })
    search_flags.add_argument('--auction',
                              metavar='Auction',
                              help="Place bids up to PRICE_MAX",
                              action='store_true',
                              widget='BlockCheckbox',
                              gooey_options={
                                  'label_color': '#4B5F83',
                                  'checkbox_label': 'Enable'
                              })

    price_range = search_options.add_argument_group('Price_Range',
                                                    gooey_options={'show_border': True}
                                                    )

    price_range.add_argument('--price-min',
                             help=
                             'This'
                             # 'is a very, very, very long help text '
                             # 'to explain a very, very, very important input value. '
                             )
    price_range.add_argument('--price-max', help='max price')

    args = parser.parse_args()
    print(args)
    print("Hiya!")
    for i in range(20):
        import time
        print('Howdy', i)
        time.sleep(.3)
    # print(args.listboxie)

"""



import argparse
import os
import unittest

from gooey.gui.components.widgets.core import chooser
from gooey.tests import *


class MockWxMDD:
    def GetPaths(self):
        pass

class TestChooserResults(unittest.TestCase):

    def test_multiDirChooserGetResult(self):
        expected_outputs = [
            (None, "", [""]),

            # Windows
            ('nt', "C:", ["OS and System (C:)"]),
            ('nt', "D:\\A Folder\\Yep Another One",
             ["Other Stuff (D:)\\A Folder\\Yep Another One"]),
            ('nt', "A:\\Wow Remember Floppy Drives;E:\\Righto Then",
             ["Flipflop (A:)\\Wow Remember Floppy Drives",
              "Elephants Only (E:)\\Righto Then"])
        ]

        for osname, expected, pathsoutput in expected_outputs:
            if not osname or osname == os.name:
                chooser.MDD.MultiDirDialog = MockWxMDD
                chooser.MDD.MultiDirDialog.GetPaths = lambda self : pathsoutput
                result = chooser.MultiDirChooser.getResult(None, MockWxMDD())
                print(result)
                self.assertEqual(result, expected)

if __name__ == '__main__':
    unittest.main()



import subprocess
import gooey
import sys

@gooey.Gooey()
def main():
    parser = gooey.GooeyParser()
    args = parser.parse_args()
    import sys
    print(sys.stdout)
    # startupinfo = subprocess.STARTUPINFO()
    # startupinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
    print('begin')
    # process = subprocess.Popen(["ping", "127.0.0.1", "-n", "5", ],
    #                            shell=True, stdout=subprocess.PIPE,
    #                            stderr=subprocess.STDOUT)
    # print('process waiting')
    # process.communicate()
    # print(sys.stdout.read())
    print('done waiting')
    # if process.returncode != 0:
    #     print("An error occurred :", process.returncode)
    #     exit(1)

if __name__ == '__main__':
    main()


"""
WxPython lacks window level event hooks. Meaning, there's no
general way to subscribe to every mouse event that goes on within
the application.

To implement features which respond to clicks outside of their
immediate scope, for instance, dropdowns, a workaround in the form
of manually binding all mouse events, for every component, to a single
top level handler needs to be done.

Normally, this type of functionality would be handled by wx.PopupTransientWindow.
However, there's a long standing bug with it and the ListBox/Ctrl
classes which prevents its usage and thus forcing this garbage.

See: https://github.com/wxWidgets/Phoenix/blob/705aa63d75715f8abe484f4559a37cb6b09decb3/demo/PopupWindow.py
"""


from gooey.gui.pubsub import pub
import gooey.gui.events as events

def notifyMouseEvent(event):
    """
    Notify interested listeners of the LEFT_DOWN mouse event
    """
    # TODO: is there ever a situation where this wouldn't be skipped..?
    event.Skip()
    pub.send_message_sync(events.LEFT_DOWN, wxEvent=event)


'''
A Gooey example showing use of richtext display in the console pannel.
'''

from gooey import Gooey, GooeyParser
from colored import stylize, attr, fg, bg
from colored import fore, back, style


@Gooey(richtext_controls=True, auto_start=True)
def main():
    parser = GooeyParser(description='Just display the console')

    args = parser.parse_args()
    # print(stylize("This is bold.", attr("bold")))
    # print(stylize("This is underlined.", attr("underlined")))
    # print(stylize("This is green.", fg("green")))
    # print(stylize("This is red.", fg("red")))
    # print(stylize("This is blue and bold.", fg("blue") + attr("bold")))
    # print('%s%s Hello World !!! %s' % (fg('white'), bg('yellow'), attr('reset')))
    # print('%s Hello World !!! %s' % (fg(1), attr(0)))
    # print (fore.LIGHT_BLUE + back.RED + style.BOLD + "Hello World !!!" + style.RESET)
    # for i in range(0, 256, 40):
    #     for j in [0,1,2,4,5,7,8,21,22,24,25,27,28]:
    #         print('%s Hello World !!! %s' % (fg(i), attr(j)))
    # for i in range(256):
    #     print(stylize('Hello World !!!', bg(i) + fg(i)))
    print(stylize('Hello world!', fg('#ff0001') + attr('bold')))
    print("{} Hey, hey!".format(attr('bold')))
    print('yo')
    print('yo')
    # for j in [0,1,2,4,5,7,8,21,22,24,25,27,28]:
    #     print(stylize(str(j) + ' - Hello World !!!' , fg('red') + bg('blue') + attr(j)))

if __name__ == '__main__':
    main()


from gooey import Gooey, GooeyParser, gui


@Gooey
def main():
    parser = GooeyParser()
    parser.add_argument(
        "some_string",
        action="store",
        default="just press Start",
    )

    parser.add_argument(
        '--filteroption', choices=['sku', 'foo', 'bar'],
        help='Select the column name you want to filter data for:',
        widget='Listbox',
        required=True,
        nargs='*',
        metavar='Select Column Name',
        # default='sku'
    )
    parser.add_argument(
        '--filteroption2', choices=['sku', 'foo', 'bar'],
        help='Select the column name you want to filter data for:',
        widget='Listbox',
        required=True,
        nargs='*',
        metavar='Select Column Name',
        default='sku'
    )

    parser.add_argument(
        '--filteroption3', choices=['sku', 'foo', 'bar'],
        help='Select the column name you want to filter data for:',
        widget='Listbox',
        required=True,
        nargs='*',
        metavar='Select Column Name',
        default=['bar']
    )

    parser.add_argument(
        '--filteroption4', choices=['sku', 'foo', 'bar'],
        help='Select the column name you want to filter data for:',
        widget='Listbox',
        required=True,
        nargs='*',
        metavar='Select Column Name',
        default=['sku', 'foo']
    )

    parser.add_argument(
        '--dropdown1', choices=['sku', 'foo', 'bar'],
        help='Select the column name you want to filter data for:',
        required=True,
        nargs='*',
        metavar='Select Column Name',
    )

    parser.add_argument(
        '--dropdown2', choices=['sku', 'foo', 'bar'],
        help='Select the column name you want to filter data for:',
        required=True,
        nargs='*',
        metavar='Select Column Name',
        default='bar'
    )

    args = parser.parse_args()
    print(args, flush=True)

    # print too many messages (causes crash for me around 105k).
    for i in range(2):
        import time
        # time.sleep(.00001)
        print(i)


if __name__ == "__main__":
    main()


print("import: 'gooey'")
import gooey

print("import: 'gooey.gui'")
import gooey.gui

print("import: 'gooey.gui.components'")
import gooey.gui.components

print("import: 'gooey.gui.components.layouts'")
import gooey.gui.components.layouts

print("import: 'gooey.gui.components.widgets'")
import gooey.gui.components.widgets

print("import: 'gooey.gui.components.widgets.core'")
import gooey.gui.components.widgets.core

print("import: 'gooey.gui.components.widgets.dialogs'")
import gooey.gui.components.widgets.dialogs

print("import: 'gooey.gui.containers'")
import gooey.gui.containers

print("import: 'gooey.gui.lang'")
import gooey.gui.lang

print("import: 'gooey.gui.util'")
import gooey.gui.util

print("import: 'gooey.images'")
import gooey.images

print("import: 'gooey.languages'")
import gooey.languages

print("import: 'gooey.python_bindings'")
import gooey.python_bindings

print("import: 'gooey.tests'")
import gooey.tests

print("import: 'gooey.util'")
import gooey.util




'''
Collection of the image paths.

The module is meant to act as a singleton, hence the globals() abuse.

Image credit: kidcomic.net
'''
import os
from functools import partial

from gooey.gui.util.freeze import getResourcePath
from gooey.util.functional import merge

filenames = {
    'programIcon': 'program_icon.png',
    'successIcon': 'success_icon.png',
    'runningIcon': 'running_icon.png',
    'configIcon': 'config_icon.png',
    'errorIcon': 'error_icon.png'
}


def loadImages(targetDir):
    defaultImages = resolvePaths(getResourcePath('images'), filenames)
    return {'images': merge(defaultImages, collectOverrides(targetDir, filenames))}


def getImageDirectory(targetDir):
    return getResourcePath('images') \
           if targetDir == 'default' \
           else targetDir


def collectOverrides(targetDir, filenames):
    if targetDir == '::gooey/default':
        return {}

    pathto = partial(os.path.join, targetDir)
    if not os.path.isdir(targetDir):
        raise IOError('Unable to find the user supplied directory {}'.format(
            targetDir))

    return {varname: pathto(filename)
            for varname, filename in filenames.items()
            if os.path.exists(pathto(filename))}


def resolvePaths(dirname, filenames):
    return {key:  os.path.join(dirname, filename)
            for key, filename in filenames.items()}





import sys
from gooey import GooeyParser as ArgumentParser
from gooey import Gooey


@Gooey(terminal_font_family="Courier New")
def set_gooey():
    return


def main():
    # If no args were given, display the GUI by calling a decorated function
    if len(sys.argv) == 1:
        set_gooey()

    # Parse command line arguments
    parser = ArgumentParser(description='Testing Gooey DirChooser.')
    parser.add_argument("path", widget="DirChooser",
                        help="Directory.")
    args = parser.parse_args()

    print ("Done")


if __name__ == '__main__':
    main()


from gooey import Gooey, GooeyParser

def main():
   parser = GooeyParser(
       description="A GooeyParser example",
      # formatter_class=argparse.ArgumentDefaultsHelpFormatter,
   )
   required_group = parser.add_argument_group(
       "Required arguments",
       "These options are mandatory "
   )

   required_group.add_argument("-a", "--a_argument", required=True, help="This is a argument.")

   required_group.add_argument(
       "-b",
       "--b_argument",
       type=int,
       required=True,
       default=5,
       help="This is a long text. This is a long text. This is a long text. This is a long text. ",
   )
   parser.parse_args()

def _main_():

   Gooey(main,
         program_name="Reproduce something",
         tabbed_groups=True)()

if __name__ == "__main__":
   _main_()


import gooey

@gooey.Gooey(dump_build_config=True)
def main():
    parser = gooey.GooeyParser()

    # parser.add_argument("--test")

    mutex_1 = parser.add_mutually_exclusive_group(required=True)
    mutex_1.add_argument('--choose-1', action='store_true', default=False)
    mutex_1.add_argument('--choose-2', action='store_true', default=False)

    # mutex_2 = parser.add_mutually_exclusive_group(required=True)
    # mutex_2.add_argument('--choose-3', action='store_true', default=False)
    # mutex_2.add_argument('--choose-4', action='store_true', default=False)

    args = parser.parse_args()
    print(args)

if __name__ == "__main__":
    main()


"""
Collection of Utility methods for creating often used, pre-styled wx Widgets
"""

import wx
from contextlib import contextmanager

from gooey.gui.three_to_four import Constants


@contextmanager
def transactUI(obj):
    """
    Coarse grain UI locking to avoid glitchy UI updates
    """
    obj.Freeze()
    try:
        yield
    finally:
        obj.Layout()
        obj.Thaw()




styles = {
    'h0': (wx.FONTFAMILY_DEFAULT, Constants.WX_FONTSTYLE_NORMAL, wx.FONTWEIGHT_BOLD, False),
    'h1': (wx.FONTFAMILY_DEFAULT, Constants.WX_FONTSTYLE_NORMAL, wx.FONTWEIGHT_BOLD, False),
    'h2': (wx.FONTFAMILY_DEFAULT, Constants.WX_FONTSTYLE_NORMAL, wx.FONTWEIGHT_NORMAL, False),
    'bold': (wx.FONTFAMILY_DEFAULT, Constants.WX_FONTSTYLE_NORMAL, wx.FONTWEIGHT_BOLD, False)
}




def make_bold(statictext):
    pointsize = statictext.GetFont().GetPointSize()
    font = wx.Font(pointsize, *styles['bold'])
    statictext.SetFont(font)


def dark_grey(statictext):
    return withColor(statictext, (54, 54, 54))


def withColor(statictext, hex):
    statictext.SetForegroundColour(hex)
    return statictext


def h0(parent, label):
    text = wx.StaticText(parent, label=label)
    font_size = text.GetFont().GetPointSize()
    font = wx.Font(int(font_size * 1.4, *styles['h0']))
    text.SetFont(font)
    return text


def h1(parent, label):
    return _header(parent, label, styles['h1'])


def h2(parent, label):
    return _header(parent, label, styles['h2'])


def _header(parent, label, styles):
    text = wx.StaticText(parent, label=label)
    font_size = text.GetFont().GetPointSize()
    font = wx.Font(int(font_size * 1.2), *styles)
    text.SetFont(font)
    return text


def horizontal_rule(parent):
    return _rule(parent, wx.LI_HORIZONTAL)


def vertical_rule(parent):
    return _rule(parent, wx.LI_VERTICAL)


def _rule(parent, direction):
    line = wx.StaticLine(parent, -1, style=direction)
    line.SetSize((10, 10))
    return line



import unittest

from tests.harness import instrumentGooey
from gooey import GooeyParser
from gooey.tests import *



class TestCheckbox(unittest.TestCase):

    def makeParser(self, **kwargs):
        parser = GooeyParser(description='description')
        parser.add_argument(
            '--widget',
            action='store_true',
            **kwargs)
        return parser


    def testInitialValue(self):
        cases = [
            # `initial` should supersede `default`
            {'inputs': {'default': False,
                        'widget': 'CheckBox',
                        'gooey_options': {'initial_value': True}},
             'expect': True},

            {'inputs': {'gooey_options': {'initial_value': True},
                        'widget': 'CheckBox'},
             'expect': True},

            {'inputs': {'gooey_options': {'initial_value': False},
                        'widget': 'CheckBox'},
             'expect': False},

            {'inputs': {'default': True,
                        'widget': 'CheckBox',
                        'gooey_options': {}},
             'expect': True},

            {'inputs': {'default': True,
                        'widget': 'CheckBox'},
             'expect': True},

            {'inputs': {'widget': 'CheckBox'},
             'expect': False}
        ]
        for case in cases:
            with self.subTest(case):
                parser = self.makeParser(**case['inputs'])
                with instrumentGooey(parser) as (app, gooeyApp):
                    widget = gooeyApp.configs[0].reifiedWidgets[0]
                    self.assertEqual(widget.getValue()['rawValue'], case['expect'])



if __name__ == '__main__':
    unittest.main()


from __future__ import unicode_literals
from __future__ import print_function
import sys
from time import sleep
from gooey import Gooey, GooeyParser


@Gooey(progress_regex=r"^progress: (-?\d+)%$",
       disable_progress_bar_animation=True,
       dump_build_config=True)
def main():
    parser = GooeyParser(prog="example_progress_bar_1")
    _ = parser.parse_args(sys.argv[1:])

    print("Step 1")

    for i in range(1, 101):
        print("progress: {}%".format(i))
        sys.stdout.flush()
        sleep(0.05)

    print("Step 2")

    print("progress: -1%")  # pulse
    sys.stdout.flush()
    sleep(3)

    print("Step 3")

    for i in range(1, 101):
        print("progress: {}%".format(i))
        sys.stdout.flush()
        sleep(0.05)


if __name__ == "__main__":
    sys.exit(main())



from gooey import Gooey, GooeyParser


@Gooey(dump_build_config=True, program_name="Widget Demo")
def main():
    desc = "Example application to show Gooey's various widgets"
    file_help_msg = "Name of the file you want to process"

    my_cool_parser = GooeyParser(description=desc)

    my_cool_parser.add_argument(
        "FileChooser", help=file_help_msg, widget="FileChooser")
    my_cool_parser.add_argument(
        "DirectoryChooser", help=file_help_msg, widget="DirChooser")
    my_cool_parser.add_argument(
        "FileSaver", help=file_help_msg, widget="FileSaver")
    my_cool_parser.add_argument(
        "MultiFileSaver", help=file_help_msg, widget="MultiFileChooser")
    my_cool_parser.add_argument("directory", help="Directory to store output")

    my_cool_parser.add_argument('-d', '--duration', default=2,
                                type=int, help='Duration (in seconds) of the program output')
    my_cool_parser.add_argument('-s', '--cron-schedule', type=int,
                                help='datetime when the cron should begin', widget='DateChooser')
    my_cool_parser.add_argument('--cron-time', type=int,
                                help='datetime when the cron should begin', widget="TimeChooser")
    my_cool_parser.add_argument(
        "-c", "--showtime", action="store_true", help="display the countdown timer")
    my_cool_parser.add_argument(
        "-p", "--pause", action="store_true", help="Pause execution")
    my_cool_parser.add_argument('-v', '--verbose', action='count')
    my_cool_parser.add_argument(
        "-o", "--overwrite", action="store_true", help="Overwrite output file (if present)")
    my_cool_parser.add_argument(
        '-r', '--recursive', choices=['yes', 'no'], help='Recurse into subfolders')
    my_cool_parser.add_argument(
        "-w", "--writelog", default="writelogs", help="Dump output to local file")
    my_cool_parser.add_argument(
        "-e", "--error", action="store_true", help="Stop process on error (default: No)")
    verbosity = my_cool_parser.add_mutually_exclusive_group()
    verbosity.add_argument('-t', '--verbozze', dest='verbose',
                           action="store_true", help="Show more details")
    verbosity.add_argument('-q', '--quiet', dest='quiet',
                           action="store_true", help="Only output on error")

    args = my_cool_parser.parse_args()
    print("Hey")


def here_is_more():
    pass


if __name__ == '__main__':
    main()


import os
from gooey.python_bindings.gooey_decorator import Gooey
from gooey.python_bindings.gooey_parser import GooeyParser
from gooey.gui.util.freeze import localResourcePath as local_resource_path
from gooey.python_bindings import constants
from gooey.gui.components.filtering.prefix_filter import PrefixTokenizers
from gooey.gui.components.options import options
__version__ = '1.0.8'



"""
App wide event registry

Everything in the application is communicated via pubsub. These are the events
that tie everything together.
"""

import wx

WINDOW_STOP     = wx.Window.NewControlId()
WINDOW_CANCEL   = wx.Window.NewControlId()
WINDOW_CLOSE    = wx.Window.NewControlId()
WINDOW_START    = wx.Window.NewControlId()
WINDOW_RESTART  = wx.Window.NewControlId()
WINDOW_EDIT     = wx.Window.NewControlId()

WINDOW_CHANGE   = wx.Window.NewControlId()
PANEL_CHANGE    = wx.Window.NewControlId()
LIST_BOX        = wx.Window.NewControlId()

CONSOLE_UPDATE  = wx.Window.NewControlId()
EXECUTION_COMPLETE = wx.Window.NewControlId()
PROGRESS_UPDATE = wx.Window.NewControlId()
TIME_UPDATE    = wx.Window.NewControlId()

USER_INPUT = wx.Window.NewControlId()

LEFT_DOWN = wx.Window.NewControlId()




'''
Main runner entry point for Gooey.
'''

import wx
# wx.html and wx.xml imports required here to make packaging with
# pyinstaller on OSX possible without manually specifying `hidden_imports`
# in the build.spec
import wx.html
import wx.xml
import wx.richtext  # Need to be imported before the wx.App object is created.
import wx.lib.inspection
from gooey.gui.lang import i18n

from gooey.gui import image_repository
from gooey.gui.containers.application import GooeyApplication
from gooey.util.functional import merge


def run(build_spec):
    app, _ = build_app(build_spec)
    app.MainLoop()


def build_app(build_spec):
    app = wx.App(False)
    return _build_app(build_spec, app)


def _build_app(build_spec, app):
    """
    Note: this method is broken out with app as
    an argument to facilitate testing.
    """
    # use actual program name instead of script file name in macOS menu
    app.SetAppDisplayName(build_spec['program_name'])

    i18n.load(build_spec['language_dir'], build_spec['language'], build_spec['encoding'])
    imagesPaths = image_repository.loadImages(build_spec['image_dir'])
    gapp = GooeyApplication(merge(build_spec, imagesPaths))
    # wx.lib.inspection.InspectionTool().Show()
    gapp.Show()
    return (app, gapp)



import os

from gooey import Gooey, GooeyParser

@Gooey()
def main():
    parser = GooeyParser(description='Just display the console')

    parser.add_argument('--host', help='Ze host!', default=os.environ.get('HOST'))
    group = parser.add_mutually_exclusive_group(required=False,
                                                # gooey_options={"initial_selection": 0}
                                                )
    group.add_argument("-b", type=str)
    group.add_argument("-d", type=str, widget="DateChooser")
    args = parser.parse_args()
    print(args)

if __name__ == '__main__':
    main()


import sys
from gooey import Gooey, GooeyParser


@Gooey()
def gui():
    parser = GooeyParser(description='Process')

    parser.add_argument(
        '-f', '--foo',
        metavar='Some Flag1',
        action='store_true',
        default=True)  # BUG: always yields True!  (works only when default=False)

    parser.add_argument(
        '-b', '--bar',
        metavar='Some Flag2',
        action='store_false',
        default=False)  # BUG: always yields False!  (works only when default=True)

    print(sys.argv)
    args = vars(parser.parse_args())
    return args


if __name__ == '__main__':
    var = gui()
    print('var:', var)  # <--watch output to see the bug




import math
import random
from functools import reduce

random.seed(0)

data = [(random.randint(0, 20),  random.randint(0, 20)) for _ in range(100)]

def vectsum(points):
    return reduce(lambda acc, val: (acc[0] + val[0], acc[1] + val[1]), points)

def vectdiv(a, b):
    return (a[0] / b[0], a[1] / b[1])

def direct_kmeans(points):
    centeroids = [random.choice(data) for _ in range(5)]

    clusters = {c: [] for c in centeroids}
    while True:
        for p1, p2 in points:
            closest = math.inf
            closest_centeroid = None
            for c1, c2 in centeroids:
                distance = math.pow(c1 - p1, 2) + math.pow(c2 - p2, 2)
                if distance < closest:
                    closest = distance
                    closest_centeroid = (c1,c2)

            clusters[closest_centeroid].append((p1,p2))
        print('before')
        print(clusters)
        clusters = {vectdiv(k, vectsum(v)) : [] for k,v in clusters.items()}
        break
    print('after')
    print(clusters)









direct_kmeans(data)



from gooey.gui.components.widgets.dropdown import Dropdown

from gooey.gui import formatters


class Counter(Dropdown):

    def setValue(self, value):
        index = self._meta['choices'].index(value) + 1
        self.widget.SetSelection(index)

    def formatOutput(self, metadata, value):
        return formatters.counter(metadata, value)



from gooey import Gooey, GooeyParser, options


# @Gooey(program_name='1.0.7 Demo')
# def main():
#     parser = GooeyParser(description='Some words')
#     parser.add_argument(
#         '--filteroption',
#         help='General text input',
#         metavar='Select Column Name',
#         gooey_options={
#             'placeholder': 'I am a placeholder!',
#             'full_width': True,
#             'show_label': False,
#         }
#     )
#
#     parser.add_argument(
#         '--filteroption2',
#         help='Textareas do it, too',
#         metavar='Select Column Name',
#         widget='Textarea',
#         gooey_options={
#             'placeholder': 'Whoa, Me too!',
#             'full_width': True,
#             'show_label': False
#         }
#     )
#
#     parser.add_argument(
#         '--filteroption3',
#         help='Password fields',
#         metavar='Password',
#         widget='PasswordField',
#         gooey_options={
#             'placeholder': 'Enter a secret here. *****',
#             'full_width': True,
#             'show_label': False
#         }
#     )
#     parser.add_argument(
#         '--filteroption4',
#         help='And all the choosers!',
#         metavar='Password',
#         widget='FileChooser',
#         gooey_options={
#             'placeholder': 'What file you want?',
#             'full_width': True,
#             'show_label': False
#         }
#     )
#     args = parser.parse_args()
#     print(args)


@Gooey(program_name='1.0.7 Demo')
def main():
    parser = GooeyParser(description='Some words')
    parser.add_argument(
        '--integer',
        help='Integer input field',
        metavar='Integers',
        # widget='IntegerField',
        gooey_options=options.IntegerField(
            validator={
                'test': 'int(user_input) < 10',
                'message': 'must be lower than 10!'
            },
            min=0,
            max=10,
            increment=1,
            full_width=True
        )
    )
    parser.add_argument(
        '--decimal',
        help='Decimal input field',
        metavar='Decimals',
        widget='DecimalField',
        gooey_options=options.DecimalField(
            min=0.0,
            max=0.1,
            increment=0.01,
            precision=2,
            full_width=True
        )
    )

    parser.add_argument(
        '--slider',
        help='Slider input field',
        metavar='Integer Slider',
        widget='Slider',
        gooey_options=options.Slider(
            min=0,
            max=1000,
            increment=1,
            full_width=True
        )
    )

    args = parser.parse_args()
    print(args)

if __name__ == '__main__':
    main()


import os
import sys
import warnings
import textwrap
from gooey.python_bindings import argparse_to_json
from gooey.gui.util.quoting import quote
from gooey.python_bindings import constants
from gooey.python_bindings import gooey_decorator
from gooey.gui.util.functional import merge_dictionaries

default_layout = {
    'widgets': [{
      'type': 'CommandField',
      'required': True,
      'data': {
        'display_name': 'Enter Commands',
        'help': 'Enter command line arguments',
        'nargs': '',
        'commands': '',
        'choices': [],
        'default': None,
      }
    }],
}


def create_from_parser(parser, source_path, **kwargs):

  run_cmd = kwargs.get('target')
  if run_cmd is None:
    if hasattr(sys, 'frozen'):
      run_cmd = quote(source_path)
    else:
      run_cmd = '{} -u {}'.format(quote(sys.executable), quote(source_path))

  build_spec = {
      'language':             kwargs.get('language', 'english'),
      'target':               run_cmd,
      # when running with a custom target, there is no need to inject
      # --ignore-gooey into the CLI args
      'suppress_gooey_flag':  kwargs.get('suppress_gooey_flag') or False,
      'program_name':         kwargs.get('program_name') or os.path.basename(sys.argv[0]).replace('.py', ''),
      'program_description':  kwargs.get('program_description') or '',
      'sidebar_title':        kwargs.get('sidebar_title', 'Actions'),
      'default_size':         kwargs.get('default_size', (610, 530)),
      'auto_start':           kwargs.get('auto_start', False),
      'show_advanced':        kwargs.get('advanced', True),
      'run_validators':       kwargs.get('run_validators', True),
      'encoding':             kwargs.get('encoding', 'utf-8'),
      'show_stop_warning':    kwargs.get('show_stop_warning', True),
      'show_success_modal':   kwargs.get('show_success_modal', True),
      'show_failure_modal':   kwargs.get('show_failure_modal', True),
      'force_stop_is_error':  kwargs.get('force_stop_is_error', True),
      'poll_external_updates':kwargs.get('poll_external_updates', False),
      'return_to_config':     kwargs.get('return_to_config', False),
      'show_restart_button':  kwargs.get('show_restart_button', True),
      'requires_shell':       kwargs.get('requires_shell', True),
      'menu':                 kwargs.get('menu', []),
      'clear_before_run':     kwargs.get('clear_before_run', False),
      'fullscreen':           kwargs.get('fullscreen', False),

      # Legacy/Backward compatibility interop
      'use_legacy_titles':    kwargs.get('use_legacy_titles', True),
      'num_required_cols':    kwargs.get('required_cols', 1),
      'num_optional_cols':    kwargs.get('optional_cols', 3),
      'manual_start':         False,
      'monospace_display':    kwargs.get('monospace_display', False),

      'image_dir':            kwargs.get('image_dir'),
      'language_dir':         kwargs.get('language_dir'),
      'progress_regex':       kwargs.get('progress_regex'),
      'progress_expr':        kwargs.get('progress_expr'),
      'hide_progress_msg':    kwargs.get('hide_progress_msg', False),
      'timing_options':       merge_dictionaries(gooey_decorator.defaults.get('timing_options'),kwargs.get('timing_options')),
      'disable_progress_bar_animation': kwargs.get('disable_progress_bar_animation'),
      'disable_stop_button':  kwargs.get('disable_stop_button'),

      # Layouts
      'navigation':           kwargs.get('navigation', constants.SIDEBAR),
      'show_sidebar':         kwargs.get('show_sidebar', False),
      'tabbed_groups':        kwargs.get('tabbed_groups', False),
      'group_by_type':        kwargs.get('group_by_type', True),

      # styles
      'body_bg_color':        kwargs.get('body_bg_color', '#f0f0f0'),
      'header_bg_color':      kwargs.get('header_bg_color', '#ffffff'),
      'header_height':        kwargs.get('header_height', 90),
      'header_show_title':    kwargs.get('header_show_title', True),
      'header_show_subtitle': kwargs.get('header_show_subtitle', True),
      'header_image_center':  kwargs.get('header_image_center', False),
      'footer_bg_color':      kwargs.get('footer_bg_color', '#f0f0f0'),
      'sidebar_bg_color':     kwargs.get('sidebar_bg_color', '#f2f2f2'),

      # font family, weight, and size are determined at runtime
      'terminal_panel_color': kwargs.get('terminal_panel_color', '#F0F0F0'),
      'terminal_font_color':  kwargs.get('terminal_font_color', '#000000'),
      'terminal_font_family': kwargs.get('terminal_font_family', None),
      'terminal_font_weight': get_font_weight(kwargs),
      'terminal_font_size':   kwargs.get('terminal_font_size', None),
      'richtext_controls':    kwargs.get('richtext_controls', False),
      'error_color':          kwargs.get('error_color', '#ea7878')
  }

  if build_spec['monospace_display']:
      warnings.warn('Gooey Option `monospace_display` is a legacy option.\n'
                    'See the terminal_font_x options for more flexible control '
                    'over Gooey\'s text formatting')


  build_spec['program_description'] = build_spec['program_description'] or parser.description or ''

  layout_data = (argparse_to_json.convert(parser, **build_spec)
                   if build_spec['show_advanced']
                   else default_layout.items())

  build_spec.update(layout_data)

  if len(build_spec['widgets']) > 1:
    # there are subparsers involved
    build_spec['show_sidebar'] = True

  return build_spec



def get_font_weight(kwargs):
    error_msg = textwrap.dedent('''
    Unknown font weight {}. 
    
    The available weights can be found in the `constants` module. 
    They're prefixed with "FONTWEIGHT" (e.g. `FONTWEIGHT_BOLD`)
    
    example code:    
    
    ```
    from gooey import constants
    @Gooey(terminal_font_weight=constants.FONTWEIGHT_NORMAL)
    ```   
    ''')
    weights = {
        constants.FONTWEIGHT_THIN,
        constants.FONTWEIGHT_EXTRALIGHT,
        constants.FONTWEIGHT_LIGHT,
        constants.FONTWEIGHT_NORMAL,
        constants.FONTWEIGHT_MEDIUM,
        constants.FONTWEIGHT_SEMIBOLD,
        constants.FONTWEIGHT_BOLD,
        constants.FONTWEIGHT_EXTRABOLD,
        constants.FONTWEIGHT_HEAVY,
        constants.FONTWEIGHT_EXTRAHEAVY
    }
    weight = kwargs.get('terminal_font_weight', constants.FONTWEIGHT_NORMAL)
    if weight not in weights:
        raise ValueError(error_msg.format(weight))
    return weight




import unittest

from gooey import GooeyParser
from gooey.tests import *
from tests.harness import instrumentGooey


class TestRadioGroupBehavior(unittest.TestCase):


    def mutext_group(self, options):
        """
        Basic radio group consisting of two options.
        """
        parser = GooeyParser()
        group = parser.add_mutually_exclusive_group(**options)
        group.add_argument("-b", type=str)
        group.add_argument("-d", type=str, widget="DateChooser")
        return parser


    def test_initial_selection_options(self):
        """
        Ensure that the initial_selection GooeyOption behaves as expected.
        """
        # each pair in the below datastructure represents input/output
        # First position: kwargs which will be supplied to the parser
        # Second position: expected indices which buttons/widgets should be enabled/disabled
        testCases = [
            [{'required': True, 'gooey_options': {}},
             {'selected': None, 'enabled': [], 'disabled': [0, 1]}],

            # Issue #517 - initial section with required=True was not enabling
            # the inner widget
            [{'required': True, 'gooey_options': {"initial_selection": 0}},
             {'selected': 0, 'enabled': [0], 'disabled': [1]}],

            [{'required': True, 'gooey_options': {"initial_selection": 1}},
             {'selected': 1, 'enabled': [1], 'disabled': [0]}],

            [{'required': False, 'gooey_options': {}},
             {'selected': None, 'enabled': [], 'disabled': [0, 1]}],

            [{'required': False, 'gooey_options': {"initial_selection": 0}},
             {'selected': 0, 'enabled': [0], 'disabled': [1]}],

            [{'required': False, 'gooey_options': {"initial_selection": 1}},
             {'selected': 1, 'enabled': [1], 'disabled': [0]}],
        ]
        for options, expected in testCases:
            parser = self.mutext_group(options)
            with self.subTest(options):
                with instrumentGooey(parser) as (app, gooeyApp):
                    radioGroup = gooeyApp.configs[0].reifiedWidgets[0]

                    # verify that the checkboxes themselves are correct
                    if expected['selected'] is not None:
                        self.assertEqual(
                            radioGroup.selected,
                            radioGroup.radioButtons[expected['selected']])
                    else:
                        self.assertEqual(radioGroup.selected, None)

                    # verify the widgets contained in the radio group
                    # are in the correct state
                    for enabled in expected['enabled']:
                        # The widget contained within the group should be enabled
                        self.assertTrue(radioGroup.widgets[enabled].IsEnabled())

                    # make sure all widgets other than the selected
                    # are disabled
                    for enabled in expected['disabled']:
                        self.assertFalse(radioGroup.widgets[enabled].IsEnabled())


    def test_optional_radiogroup_click_behavior(self):
        """
        Testing that select/deselect behaves as expected
        """
        testcases = [
            self.click_scenarios_optional_widget(),
            self.click_scenarios_required_widget(),
            self.click_scenarios_initial_selection()
        ]

        for testcase in testcases:
            with self.subTest(testcase['name']):
                # wire up the parse with our test case options
                parser = self.mutext_group(testcase['input'])

                with instrumentGooey(parser) as (app, gooeyApp):
                    radioGroup = gooeyApp.configs[0].reifiedWidgets[0]

                    for scenario in testcase['scenario']:
                        targetButton = scenario['clickButton']

                        event = wx.CommandEvent(wx.wxEVT_LEFT_DOWN, wx.Window.NewControlId())
                        event.SetEventObject(radioGroup.radioButtons[targetButton])

                        radioGroup.radioButtons[targetButton].ProcessEvent(event)

                        expectedEnabled, expectedDisabled = scenario['postState']

                        for index in expectedEnabled:
                            self.assertEqual(radioGroup.selected, radioGroup.radioButtons[index])
                            self.assertTrue(radioGroup.widgets[index].IsEnabled())

                        for index in expectedDisabled:
                            self.assertNotEqual(radioGroup.selected, radioGroup.radioButtons[index])
                            self.assertFalse(radioGroup.widgets[index].IsEnabled())


    def click_scenarios_optional_widget(self):
        return {
            'name': 'click_scenarios_optional_widget',
            'input': {'required': False},
            'scenario': [
                # clicking enabled the button
                {'clickButton': 0,
                 'postState': [[0], [1]]},

                # clicking again disables the button (*when not required*)
                {'clickButton': 0,
                 'postState': [[], [0, 1]]},

                # clicking group 2 enabled it
                {'clickButton': 1,
                 'postState': [[1], [0]]},

                # and similarly clicking group 2 again disables it
                {'clickButton': 1,
                 'postState': [[], [0, 1]]},

                # enable second group
                {'clickButton': 1,
                 'postState': [[1], [0]]},

                # can switch to group one
                {'clickButton': 0,
                 'postState': [[0], [1]]},
            ]
        }

    def click_scenarios_required_widget(self):
        return {
            'name': 'click_scenarios_required_widget',
            'input': {'required': True},
            'scenario': [
                # clicking enables the button
                {'clickButton': 0,
                 'postState': [[0], [1]]},

                # unlike the the optional case, this
                # has no effect. You cannot _not_ select something
                # when it is required.
                {'clickButton': 0,
                 'postState': [[0], [1]]},

                # we can select a different button
                {'clickButton': 1,
                 'postState': [[1], [0]]},

                # again, if we click it again, we cannot deselect it
                {'clickButton': 1,
                 'postState': [[1], [0]]},

                # we can click back to the other group
                {'clickButton': 0,
                 'postState': [[0], [1]]},
            ]}

    def click_scenarios_initial_selection(self):
        return {
            'name': 'click_scenarios_initial_selection',
            'input': {'required': False, 'gooey_options': {'initial_selection': 0}},
            'scenario': [
                # we start already selected via GooeyOptions. As such,
                # clicking on the radiobutton should deselect it
                {'clickButton': 0,
                 'postState': [[], [0, 1]]},
                # clicking again reselected it
                {'clickButton': 0,
                 'postState': [[0], [1]]},
            ]}



if __name__ == '__main__':
    unittest.main()


'''
Created on Dec 21, 2013
 __          __  _
 \ \        / / | |
  \ \  /\  / /__| | ___ ___  _ __ ___   ___
   \ \/  \/ / _ \ |/ __/ _ \| '_ ` _ \ / _ \
    \  /\  /  __/ | (_| (_) | | | | | |  __/
  ___\/__\/ \___|_|\___\___/|_| |_| |_|\___|
 |__   __|
    | | ___
    | |/ _ \
    | | (_) |
   _|_|\___/                    _ _
  / ____|                      | | |
 | |  __  ___   ___   ___ _   _| | |
 | | |_ |/ _ \ / _ \ / _ \ | | | | |
 | |__| | (_) | (_) |  __/ |_| |_|_|
  \_____|\___/ \___/ \___|\__, (_|_)
                           __/ |
                          |___/

@author: Chris
'''

from gooey.python_bindings.gooey_decorator import Gooey
from gooey.python_bindings.gooey_parser import GooeyParser



long_intro = '''
Guess again. And remember, don't do anything that affects anything, unless it turns out you were supposed to, in which case, for the love of God, don't not do it! Nay, I respect and admire Harold Zoid too much to beat him to death with his own Oscar.

Bender?! You stole the atom. Noooooo! Ah, computer dating. It's like pimping, but you rarely have to use the phrase "upside your head." The alien mothership is in orbit here. If we can hit that bullseye, the rest of the dominoes will fall like a house of cards. Checkmate.

That's the ONLY thing about being a slave. Ooh, name it after me! You're going back for the Countess, aren't you? Ooh, name it after me! We don't have a brig. I had more, but you go ahead.

Say it in Russian! You guys go on without me! I'm going to go… look for more stuff to steal! Bite my shiny metal ass. Yeah, lots of people did.
'''

@Gooey(
    program_name='Advanced Layout Groups',
    sidebar_title="Your Custom Title",
    show_sidebar=False,
    dump_build_config=True,
    tabbed_groups=True,
)
def main():
    import sys
    print(sys.argv)
    my_cool_parser = GooeyParser(description='Hai', add_help=False)

    description_area = my_cool_parser.add_argument_group(
        "Introduction",
        long_intro,
        gooey_options={
            'show_border': False,
            'show_underline': False,
        }
    )

    # We need at least on
    description_area.add_argument(
        '-nothing',
        gooey_options={
            'visible': False,
        }
    )

    categories = my_cool_parser.add_argument_group(
        'Categories',
        description='There are 13 species of crocodiles, so there are many different ' +
                    'sizes of crocodile. The smallest crocodile is the dwarf crocodile. ' +
                    'It grows to about 5.6 feet (1.7 meters) in length and weighs 13 to 15 pounds ',
        gooey_options={
            'show_border': False,
            'label_color': '#FF9900',
            'columns': 2,
            # 'margin_top': 90
        }
    )

    categories.add_argument(
        '--parent-category',
        metavar='Parent Category',
        help='This is a very, very, very long help text '
                             'to explain a very, very, very important input value. '
                             'Unfortunately, the end of this long message is cropped. ',
        choices=['a', 'b', 'c'],
        required=True)

    args = my_cool_parser.parse_args()
    print("Hiya!")


if __name__ == '__main__':
    main()



import argparse
from gooey import Gooey


@Gooey
def main():
    parser = argparse.ArgumentParser(prog="aria2p")
    subparsers = parser.add_subparsers(dest="subcommand", metavar="", prog="aria2p")
    subcommand_help = "Show this help message and exit."

    def subparser(command, text, **kwargs):
        sub = subparsers.add_parser(command, add_help=False, help=text, description=text, **kwargs)
        sub.add_argument("-h", "--help", action="help", help=subcommand_help)
        return sub

    pause_parser = subparser("pause", "Pause downloads.", aliases=["stop"])

    args = parser.parse_args()

# if __name__ == '__main__':
main()


import unittest

from gooey import GooeyParser
from gooey.tests import *

class TestConstraints(unittest.TestCase):

    def test_listbox_constraints(self):
        """
        Listbox widgets must be provided a nargs option
        """

        # Trying to create a listbox widget without specifying nargs
        # throws an error
        with self.assertRaises(ValueError):
            parser = GooeyParser()
            parser.add_argument('one', choices=['one', 'two'], widget='Listbox')

        # Listbox with an invalid nargs value throws an error
        with self.assertRaises(ValueError):
            parser = GooeyParser()
            parser.add_argument(
                'one', choices=['one', 'two'], widget='Listbox', nargs='?')

        # Listbox with an invalid nargs value throws an error
        with self.assertRaises(ValueError):
            parser = GooeyParser()
            parser.add_argument(
                'one', choices=['one', 'two'], widget='Listbox', nargs=3)

        # valid nargs throw no errors
        for narg in ['*', '+']:
            parser = GooeyParser()
            parser.add_argument(
                'one', choices=['one', 'two'], widget='Listbox', nargs=narg)



    def test_visibility_constraint(self):
        """
        When visible=False in Gooey config, the user MUST supply either
        a custom validator or a default value.
        """
        # added without issue
        parser = GooeyParser()
        parser.add_argument('one')

        # still fine
        parser = GooeyParser()
        parser.add_argument('one', gooey_options={'visible': True})

        # trying to hide an input without a default or custom validator
        # results in an error
        with self.assertRaises(ValueError):
            parser = GooeyParser()
            parser.add_argument('one', gooey_options={'visible': False})

        # explicit default=None; still error
        with self.assertRaises(ValueError):
            parser = GooeyParser()
            parser.add_argument(
                'one',
                default=None,
                gooey_options={'visible': False})

        # default = empty string. Still error
        with self.assertRaises(ValueError):
            parser = GooeyParser()
            parser.add_argument(
                'one',
                default='',
                gooey_options={'visible': False})

        # default = valid string. No Error
        parser = GooeyParser()
        parser.add_argument(
            'one',
            default='Hello',
            gooey_options={'visible': False})

        # No default, but custom validator: Success
        parser = GooeyParser()
        parser.add_argument(
            'one',
            gooey_options={
                'visible': False,
                'validator': {'test': 'true'}
            })

        # default AND validator, still fine
        parser = GooeyParser()
        parser.add_argument(
            'one',
            default='Hai',
            gooey_options={
                'visible': False,
                'validator': {'test': 'true'}
            })


import wx

class BasicTextConsole(wx.TextCtrl):
    def __init__(self, parent):
        super(BasicTextConsole, self).__init__(parent, -1, "", style=wx.TE_MULTILINE | wx.TE_READONLY | wx.TE_RICH | wx.TE_AUTO_URL )



from gooey import Gooey, GooeyParser


@Gooey
def main():
    parser = GooeyParser()
    parent = parser.add_argument_group('Search Options', gooey_options={
        'columns': 2
    })
    parent.add_argument('--query-string', help='the search string')

    child_one = parent.add_argument_group('flags', gooey_options={'show_border': True})
    child_one.add_argument('--option1', help='some text here')

    child_two = parent.add_argument_group('price', gooey_options={'show_border': True})
    child_two.add_argument('--option2', help='some text here')
    args = parser.parse_args()


if __name__ == '__main__':
    main()


import argparse
from gooey import Gooey

ConstantArray = [
        'foo',
        'bar',
        'baz',
        'gat'
]


def fooobar():
    parser = argparse.ArgumentParser()
    parser.add_argument("echo", help="sup fam")
    args = parser.parse_args()

    print(args)


if __name__ == "__main__":
    Gooey(fooobar)()



from gooey.gui import formatters
from gooey.gui.components.widgets.bases import TextContainer
from gooey.gui.components.widgets.core.text_input import TextInput


class TextField(TextContainer):
    widget_class = TextInput

    def getWidgetValue(self):
        return self.widget.getValue()

    def setValue(self, value):
        self.widget.setValue(str(value))

    def setPlaceholder(self, value):
        self.widget.SetHint(value)

    def formatOutput(self, metatdata, value):
        return formatters.general(metatdata, value)




from contextlib import contextmanager

from gooey.gui.components.widgets.bases import TextContainer
import wx

from gooey.gui import formatters
from gooey.gui.lang.i18n import _


class Dropdown(TextContainer):
    _gooey_options = {
        'placeholder': str,
        'readonly': bool,
        'enable_autocomplete': bool
    }
    def getWidget(self, parent, *args, **options):
        default = _('select_option')
        return wx.ComboBox(
            parent=parent,
            id=-1,
            # str conversion allows using stringyfiable values in addition to pure strings
            value=str(default),
            choices=[str(default)] + [str(choice) for choice in self._meta['choices']],
            style=wx.CB_DROPDOWN)

    def setOptions(self, options):
        with self.retainSelection():
            self.widget.Clear()
            self.widget.SetItems([_('select_option')] + options)

    def setValue(self, value):
        ## +1 to offset the default placeholder value
        index = self._meta['choices'].index(value) + 1
        self.widget.SetSelection(index)

    def getWidgetValue(self):
        value = self.widget.GetValue()
        # filter out the extra default option that's
        # appended during creation
        if value == _('select_option'):
            return None
        return value

    def formatOutput(self, metadata, value):
        return formatters.dropdown(metadata, value)

    @contextmanager
    def retainSelection(self):
        """"
        Retains the selected dropdown option (when possible)
        across mutations due to dynamic updates.
        """
        prevSelection = self.widget.GetSelection()
        prevValue = self.widget.GetValue()
        try:
            yield
        finally:
            current_at_index = self.widget.GetString(prevSelection)
            if prevValue == current_at_index:
                self.widget.SetSelection(prevSelection)
            else:
                self.widget.SetSelection(0)



from gooey import Gooey, GooeyParser


@Gooey
def main():
    parser = GooeyParser()
    args = parser.parse_args()
    print('''
Who said that? SURE you can die! You want to die?! Enough about your 
promiscuous mother, Hermes! We have bigger problems. Does anybody else feel 
jealous and aroused and worried? There, now he's trapped in a book I 
wrote: a crummy world of plot holes and spelling errors!

http://fillerama.io/
    ''')


if __name__ == '__main__':
    main()


import unittest

from tests.harness import instrumentGooey
from gooey import GooeyParser
from gooey.tests import *



class TestCounter(unittest.TestCase):

    def makeParser(self, **kwargs):
        parser = GooeyParser(description='description')
        parser.add_argument(
            '--widget',
            action='count',
            widget="Counter",
            **kwargs)
        return parser


    def testInitialValue(self):
        cases = [
            # `initial` should supersede `default`
            {'inputs': {'default': 1,
                        'gooey_options': {'initial_value': 3}},
             'expect': '3'},

            {'inputs': {'gooey_options': {'initial_value': 1}},
             'expect': '1'},

            {'inputs': {'default': 2,
                        'gooey_options': {}},
             'expect': '2'},

            {'inputs': {'default': 1},
             'expect': '1'},

            {'inputs': {},
             'expect': None}
        ]
        for case in cases:
            with self.subTest(case):
                parser = self.makeParser(**case['inputs'])
                with instrumentGooey(parser) as (app, gooeyApp):
                    widget = gooeyApp.configs[0].reifiedWidgets[0]
                    self.assertEqual(widget.getValue()['rawValue'], case['expect'])



if __name__ == '__main__':
    unittest.main()


'''
Created on Dec 21, 2013
 __          __  _
 \ \        / / | |
  \ \  /\  / /__| | ___ ___  _ __ ___   ___
   \ \/  \/ / _ \ |/ __/ _ \| '_ ` _ \ / _ \
    \  /\  /  __/ | (_| (_) | | | | | |  __/
  ___\/__\/ \___|_|\___\___/|_| |_| |_|\___|
 |__   __|
    | | ___
    | |/ _ \
    | | (_) |
   _|_|\___/                    _ _
  / ____|                      | | |
 | |  __  ___   ___   ___ _   _| | |
 | | |_ |/ _ \ / _ \ / _ \ | | | | |
 | |__| | (_) | (_) |  __/ |_| |_|_|
  \_____|\___/ \___/ \___|\__, (_|_)
                           __/ |
                          |___/

@author: Chris
'''

from gooey.python_bindings.gooey_decorator import Gooey
from gooey.python_bindings.gooey_parser import GooeyParser


@Gooey(
    program_name='Advanced Layout Groups',
    sidebar_title="Your Custom Title",
    show_sidebar=False,
    dump_build_config=True,
    tabbed_groups=False,
    # body_bg_color='#ffffff'
    menu=[{
        'name': 'File',
        'items': [{
                'type': 'AboutDialog',
                'menuTitle': 'About',
                'name': 'Gooey Layout Demo',
                'description': 'An example of Gooey\'s layout flexibility',
                'version': '1.2.1',
                'copyright': '2018',
                'website': 'https://github.com/chriskiehl/Gooey',
                'developer': 'http://chriskiehl.com/',
                'license': 'MIT'
            }, {
                'type': 'MessageDialog',
                'menuTitle': 'Information',
                'caption': 'My Message',
                'message': 'I am demoing an informational dialog!'
            }, {
                'type': 'Link',
                'menuTitle': 'Visit Our Site',
                'url': 'https://github.com/chriskiehl/Gooey'
            }]
        },{
        'name': 'Help',
        'items': [{
            'type': 'Link',
            'menuTitle': 'Documentation',
            'url': 'https://www.readthedocs.com/foo'
        }]
    }]
)
def main():
    message = (
        'Hi there!\n\n' 
        'Welcome to Gooey! \nThis is a demo of the flexible layouts and overall' 
        'customization you can achieve by using argument groups and '
        'the new gooey_options feature.')



    import sys
    print(sys.argv)
    desc = "Example application to show Gooey's various widgets"
    file_help_msg = "Name of the file you want to process"
    my_cool_parser = GooeyParser(description=desc, add_help=False)

    categories = my_cool_parser.add_argument_group(
        'Example 1',
        description='This is the default group style',
        gooey_options={
            'show_underline': True,
            'show_border': False,
            # 'label_color': '#FF9900',
            'columns': 1,
            # 'margin_top': 90
        }
    )

    categories.add_argument(
        '--subcategoryasdf2asdf',
        metavar='Parent Category',
        help='Select Subcategory',
        choices=['a', 'b', 'c'],
        required=True,
    )

    categories.add_argument(
        '--subcategory',
        metavar='Subcategory',
        help='Select Subcategory',
        choices=['a', 'b', 'c'],
        required=True,
    )

    categories1 = my_cool_parser.add_argument_group(
        'Example 2',
        description='This is an argument group with no horizontal line break',
        gooey_options={
            'show_underline': False,
            'show_border': False,
        }
    )

    categories1.add_argument(
        '--subcategoryasdf2asdfasdf',
        metavar='Parent Category',
        help='Select Subcategory',
        choices=['a', 'b', 'c'],
        required=True,
    )

    categories1.add_argument(
        '--subcategory1',
        metavar='Subcategory',
        help='Select Subcategory',
        choices=['a', 'b', 'c'],
        required=True,
    )


    categories2 = my_cool_parser.add_argument_group(
        'Example 3',
        description='This is an argument group with show_border = True',
        gooey_options={
            'show_underline': False,
            'show_border': True,
            # 'label_color': '#FF9900',
            # 'columns': 2,
            # 'margin_top': 90
        }
    )

    categories2.add_argument(
        '--subcategoryasdf2',
        metavar='Parent Category',
        help='Select Subcategory',
        choices=['a', 'b', 'c'],
        required=True,
    )

    categories2.add_argument(
        '--subcategory2',
        metavar='Subcategory',
        help='Select Subcategory',
        choices=['a', 'b', 'c'],
        required=True,
    )





    my_cool_parser.print_help()
    args = my_cool_parser.parse_args()
    print(args)
    print("Hiya!")
    for i in range(20):
        import time
        print('Howdy', i)
        time.sleep(.3)
    # print(args.listboxie)


def here_is_smore():
    pass


if __name__ == '__main__':
    main()



from gooey import Gooey, GooeyParser


@Gooey()
def main():
    parser = GooeyParser(add_help=False)
    parser.add_argument('--c_file', widget='FileChooser')

    args = parser.parse_args()

    for i in range(4):
        import time
        # time.sleep(1)
        print('sleeping...', time.time())


if __name__ == '__main__':
    main()






from gooey import Gooey, GooeyParser


@Gooey(program_name='My Super Awesome Program',
       default_size=(670, 615),
       header_show_title=True,
       dump_build_config=True,
       menu=[{
           'name': 'Help',
           'items': [{
               'type': 'Link',
               'menuTitle': 'Visit Our Site',
               'url': 'https://github.com/chriskiehl/Gooey'
           }]
       }]
       )
def main():
    '''
    Dummy Function to create a gooey GUI and test the issue.
    '''
    parser = GooeyParser(
        description='This is my program.\nThere are many like it, but this one is mine.')
    parser.add_argument('myfolder', widget='DirChooser',
                        help='Path to directory where output will be stored.')
    args = parser.parse_args()

    print('I\'m a dummy!')


main()


from gooey import Gooey, GooeyParser


@Gooey(program_name="Time Selection", use_cmd_args=True)
def parse_args(default_name):
    parser = GooeyParser(description="Select a time!")
    parser.add_argument('--foo', metavar='Select a Time', help="Time when we should start the program", widget='TimeChooser')

    args = parser.parse_args()
    print(args)

if __name__ == '__main__':
    conf = parse_args("/sample")
    print("Done")


import json
import sys
from pprint import pprint

from gooey import Gooey, GooeyParser


@Gooey(program_name="Using Dynamic Values", poll_external_updates=True)
def main():
    parser = GooeyParser()
    parser.add_argument(
        '--name',
        metavar='name',
        widget='Dropdown',
        choices=[str(i) for i in range(500)]
    )

    args = parser.parse_args()
    pprint(args)


if __name__ == '__main__':
    from random import randint
    if 'gooey-seed-ui' in sys.argv:
        l = [str(i) for i in range(randint(1, 10))]
        print(json.dumps({'--name': l}))
        exit()
    print("-" * 80)
    pprint(sys.argv)
    main()


"""
A collection of functional utilities/helpers
"""
from functools import reduce
from copy import deepcopy
from itertools import chain, dropwhile


def getin(m, path, default=None):
    """returns the value in a nested dict"""
    keynotfound = ':com.gooey-project/not-found'
    result = reduce(lambda acc, val: acc.get(val, {keynotfound: None}), path, m)
    # falsey values like 0 would incorrectly trigger the default to be returned
    # so the keynotfound val is used to signify a miss vs just a falesy val
    if isinstance(result, dict) and keynotfound in result:
        return default
    return result


def assoc(m, key, val):
    """Copy-on-write associates a value in a dict"""
    cpy = deepcopy(m)
    cpy[key] = val
    return cpy

def dissoc(m, key, val):
    cpy = deepcopy(m)
    del cpy[key]
    return cpy

def associn(m, path, value):
    """ Copy-on-write associates a value in a nested dict """
    def assoc_recursively(m, path, value):
        if not path:
            return value
        p = path[0]
        return assoc(m, p, assoc_recursively(m.get(p,{}), path[1:], value))
    return assoc_recursively(m, path, value)


def merge(*maps):
    """Merge all maps left to right"""
    copies = map(deepcopy, maps)
    return reduce(lambda acc, val: acc.update(val) or acc, copies)


def flatmap(f, coll):
    """Applies concat to the result of applying f to colls"""
    return list(chain(*map(f, coll)))


def indexunique(f, coll):
    """Build a map from the collection keyed off of f
    e.g.
        [{id:1,..}, {id:2, ...}] => {1: {id:1,...}, 2: {id:2,...}}

    Note: duplicates, if present, are overwritten
    """
    return zipmap(map(f, coll), coll)


def findfirst(f, coll):
    """Return first occurrence matching f, otherwise None"""
    result = list(dropwhile(f, coll))
    return result[0] if result else None


def zipmap(keys, vals):
    """Return a map from keys to values"""
    return dict(zip(keys, vals))


def compact(coll):
    """Returns a new list with all falsy values removed"""
    if isinstance(coll, dict):
        return {k:v for k,v in coll.items() if v is not None}
    else:
        return list(filter(None, coll))


def ifPresent(f):
    """Execute f only if value is present and not None"""
    def inner(value):
        if value:
            return f(value)
        else:
            return True
    return inner


def identity(x):
    """Identity function always returns the supplied argument"""
    return x


def unit(val):
    return val


def bind(val, f):
    return f(val) if val else None



import unittest

from gooey import GooeyParser
from gooey.python_bindings import cmd_args
from argparse import ArgumentParser
from gooey.tests import *


class TextCommandLine(unittest.TestCase):

    def test_default_overwritten(self):
        parser = GooeyParser()
        ArgumentParser.original_parse_args = ArgumentParser.parse_args

        parser.add_argument('arg', type=int, default=0)

        # Supply 1 as command line argument, check that it overwrites argparse default
        cmd_args.parse_cmd_args(parser, ['1'])
        argdefault = next(action for action in parser._actions if action.dest == 'arg').default
        self.assertEqual(argdefault, 1)

    def test_required_not_enforced(self):
        parser = GooeyParser()
        ArgumentParser.original_parse_args = ArgumentParser.parse_args

        parser.add_argument('--arg', type=int, required=True)
        parser.add_argument('--argn', type=int, nargs='+')
        parser.add_argument('argp', type=int)
        mutex=parser.add_mutually_exclusive_group(required=True)
        mutex.add_argument('--one', action='store_true')
        mutex.add_argument('--two', action='store_true')

        # No error when we don't provide required arguments
        cmd_args.parse_cmd_args(parser)

        # Test that required/argn have been restored in parser
        argrequired = next(action for action in parser._actions if action.dest == 'arg').required
        self.assertEqual(argrequired, True)
        argnnargs = next(action for action in parser._actions if action.dest == 'argn').nargs
        self.assertEqual(argnnargs, '+')
        argpnargs = next(action for action in parser._actions if action.dest == 'argp').nargs
        self.assertEqual(argpnargs, None)
        mutexrequired = next(mutex for mutex in parser._mutually_exclusive_groups).required
        self.assertEqual(mutexrequired, True)

    def test_cmd_args_subparser(self):
        parser = GooeyParser()
        subparsers = parser.add_subparsers(dest='subparser')
        subparserA = subparsers.add_parser('A')
        subparserB = subparsers.add_parser('B')
        subparserA.add_argument('argA', type=int, default=0)
        subparserB.add_argument('argB', type=int, default=0)

        ArgumentParser.original_parse_args = ArgumentParser.parse_args

        cmd_args.parse_cmd_args(parser, ['A', '1'])

        # Check that argA is overwritten but not argB
        subparseraction = next(action for action in parser._actions if action.dest == 'subparser')
        argAdefault = next(action for action in subparseraction.choices['A']._actions if action.dest == 'argA').default
        self.assertEqual(argAdefault, 1)
        argBdefault = next(action for action in subparseraction.choices['B']._actions if action.dest == 'argB').default
        self.assertEqual(argBdefault, 0)




from gooey import Gooey, GooeyParser
import sys
import time

@Gooey(progress_regex=r"^(?P<current>\d+)/(?P<total>\d+)$",
       progress_expr="current / total * 100")
def main():
    parser = GooeyParser(prog="example_progress_bar_3")
    parser.add_argument("steps", type=int, default=15)
    parser.add_argument("delay", type=float, default=.3)
    args = parser.parse_args(sys.argv[1:])

    print("Total: 100")

    for i in range(args.steps):
        print("Current: {}".format(i + 1, args.steps))
        sys.stdout.flush()
        time.sleep(args.delay)


if __name__ == '__main__':
    main()


import wx
from wx.lib.wordwrap import wordwrap



class AutoWrappedStaticText(wx.StaticText):
    """
    Copy/pasta of wx.lib.agw.infobar.AutoWrapStaticText with 3 modifications:

        1. Extends wx.StaticText rather than GenStaticText
        2. Does not set the fore/background colors to sys defaults
        3. takes an optional `target` parameter for sizing info

    The behavior of GenStaticText's background color is pretty buggy cross-
    platform. It doesn't reliably match its parent components background
    colors[0] (for instance when rendered inside of a Notebook) which leads to
    ugly 'boxing' around the text components.

    There is either a bug in WX, or or human error on my end, which causes
    EVT_SIZE events to continuously spawn from this (and AutoWrapStaticText) but
    with ever decreasing widths (in response to the SetLabel action in the
    wrap handler). The end result is a single skinny column of letters.

    The work around is to respond the EVT_SIZE event, but follow the size of the
    `target` component rather than relying on the size of the event.

    [0] more specifically, they'll match 1:1 on paper, but still ultimately
    render differently.
    """

    def __init__(self, parent, *args, **kwargs):
        self.target = kwargs.pop('target', None)
        super(AutoWrappedStaticText, self).__init__(parent, *args, **kwargs)
        self.label = kwargs.get('label')
        self.Bind(wx.EVT_SIZE, self.OnSize)
        self.parent = parent


    def OnSize(self, event):
        """
        Handles the ``wx.EVT_SIZE`` event for :class:`AutoWrapStaticText`.

        :param `event`: a :class:`wx.SizeEvent` event to be processed.
        """

        event.Skip()
        if self.target:
            self.Wrap(self.target.GetSize().width)
        else:
            self.Wrap(self.parent.GetSize()[0])

    def Wrap(self, width):
        """
        This functions wraps the controls label so that each of its lines becomes at
        most `width` pixels wide if possible (the lines are broken at words boundaries
        so it might not be the case if words are too long).

        If `width` is negative, no wrapping is done.

        :param integer `width`: the maximum available width for the text, in pixels.

        :note: Note that this `width` is not necessarily the total width of the control,
         since a few pixels for the border (depending on the controls border style) may be added.
        """

        if width < 0:
            return

        self.Freeze()

        dc = wx.ClientDC(self)
        dc.SetFont(self.GetFont())
        text = wordwrap(self.label, width, dc)
        self.SetLabel(text, wrapped=True)

        self.Thaw()

    def SetLabel(self, label, wrapped=False):
        """
        Sets the :class:`AutoWrapStaticText` label.

        All "&" characters in the label are special and indicate that the following character is
        a mnemonic for this control and can be used to activate it from the keyboard (typically
        by using ``Alt`` key in combination with it). To insert a literal ampersand character, you
        need to double it, i.e. use "&&". If this behaviour is undesirable, use :meth:`~Control.SetLabelText` instead.

        :param string `label`: the new :class:`AutoWrapStaticText` text label;
        :param bool `wrapped`: ``True`` if this method was called by the developer using :meth:`~AutoWrapStaticText.SetLabel`,
         ``False`` if it comes from the :meth:`~AutoWrapStaticText.OnSize` event handler.

        :note: Reimplemented from :class:`wx.Control`.
        """

        if not wrapped:
            self.label = label

        wx.StaticText.SetLabel(self, label)



import webbrowser
from functools import partial

import wx

from gooey.gui import three_to_four


class MenuBar(wx.MenuBar):
    """
    Wx.MenuBar handles converting the users list of Menu Groups into
    concrete wx.Menu instances.
    """

    def __init__(self, buildSpec, *args, **kwargs):
        super(MenuBar,self).__init__(*args, **kwargs)
        self.buildSpec = buildSpec
        self.makeMenuItems(buildSpec.get('menu', []))


    def makeMenuItems(self, menuGroups):
        """
        Assign the menu groups list to wx.Menu instances
        and bind the appropriate handlers.
        """
        for menuGroup in menuGroups:
            menu = wx.Menu()
            for item in menuGroup.get('items'):
                option = menu.Append(wx.NewId(), item.get('menuTitle', ''))
                self.Bind(wx.EVT_MENU, self.handleMenuAction(item), option)
            self.Append(menu, '&' + menuGroup.get('name'))


    def handleMenuAction(self, item):
        """
        Dispatch based on the value of the type field.
        """
        handlers = {
            'Link': self.openBrowser,
            'AboutDialog': self.spawnAboutDialog,
            'MessageDialog': self.spawnMessageDialog
        }
        f = handlers[item['type']]
        return partial(f, item)


    def openBrowser(self, item, *args, **kwargs):
        """
        Open the supplied URL in the user's default browser.
        """
        webbrowser.open(item.get('url'))


    def spawnMessageDialog(self, item, *args, **kwargs):
        """
        Show a simple message dialog with the user's message and caption.
        """
        wx.MessageDialog(self, item.get('message', ''),
                               caption=item.get('caption', '')).ShowModal()


    def spawnAboutDialog(self, item, *args, **kwargs):
        """
        Fill the wx.AboutBox with any relevant info the user provided
        and launch the dialog
        """
        aboutOptions = {
            'name': 'SetName',
            'version': 'SetVersion',
            'description': 'SetDescription',
            'copyright': 'SetCopyright',
            'website': 'SetWebSite',
            'developer': 'AddDeveloper',
            'license': 'SetLicense'
        }
        about = three_to_four.AboutDialog()
        for field, method in aboutOptions.items():
            if field in item:
                getattr(about, method)(item[field])

        three_to_four.AboutBox(about)